@@ -111,6 +111,8 @@ public:
     C(PUB, 'P','U','B');
     C(NAT, 'N','A','T');
     C(RNT, 'R','N','T');
+    C(ZON, 'Z','O','N');
+    C(ZOF, 'Z','O','F');
 #undef C
 
     static const uint32_t HUB_SID = 0xffffffff;     // No client will have this sid
@@ -207,6 +209,8 @@ public:
                 C(PSR);
                 C(NAT);
                 C(RNT);
+                C(ZON);
+                C(ZOF);
             default:
                 dcdebug("Unknown ADC command: %.50s\n", aLine.c_str());
                 break;
