@@ -79,6 +79,7 @@ public:
     static const string TIGR_SUPPORT;
     static const string UCM0_SUPPORT;
     static const string BLO0_SUPPORT;
+    static const string ZLIF_SUPPORT;
 #ifdef WITH_DHT
     static const string DHT0_SUPPORT;
 #endif
@@ -136,6 +137,8 @@ private:
     void handle(AdcCommand::PSR, AdcCommand& c) noexcept;
     void handle(AdcCommand::NAT, AdcCommand& c) noexcept;
     void handle(AdcCommand::RNT, AdcCommand& c) noexcept;
+    void handle(AdcCommand::ZON, AdcCommand& c) noexcept;
+    void handle(AdcCommand::ZOF, AdcCommand& c) noexcept;
 
     template<typename T> void handle(T, AdcCommand&) { }
 
