@@ -105,7 +105,7 @@ void BufferedSocket::connect(const string& aAddress, uint16_t aPort, uint16_t lo
 
     s->create();
     setSocket(move(s));
-    sock->bind(localPort, SETTING(BIND_ADDRESS));
+    sock->bind(localPort, SETTING(BIND_IFACE)? sock->getIfaceI4(SETTING(BIND_IFACE_NAME)).c_str() : SETTING(BIND_ADDRESS));
 
     Lock l(cs);
     addTask(CONNECT, new ConnectInfo(aAddress, aPort, localPort, natRole, proxy && (SETTING(OUTGOING_CONNECTIONS) == SettingsManager::OUTGOING_SOCKS5)));
@@ -472,6 +472,7 @@ void BufferedSocket::checkSocket() {
  */
 int BufferedSocket::run() {
     dcdebug("BufferedSocket::run() start %p\n", (void*)this);
+    setThreadName("BufferedSocket");
     while(true) {
         try {
             if(!checkEvents()) {
