@@ -13,27 +13,30 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef DCPLUSPLUS_DCPP_CHAT_MESSAGE_H
 #define DCPLUSPLUS_DCPP_CHAT_MESSAGE_H
 
 #include "forward.h"
+#include <string>
 
 namespace dcpp {
 
+using std::string;
+
 struct ChatMessage {
-        string text;
+    string text;
 
-        const OnlineUser* from;
-        const OnlineUser* to;
-        const OnlineUser* replyTo;
+    const OnlineUser* from;
+    const OnlineUser* to;
+    const OnlineUser* replyTo;
 
-        bool thirdPerson;
-        time_t timestamp;
+    bool thirdPerson;
+    time_t timestamp;
 
-        string format() const;
+    string format() const;
 };
 
 } // namespace dcpp
