@@ -216,7 +216,7 @@ static const uint32_t FLOOD_ADD = 2000;
 ConnectionManager::Server::Server(bool secure_, uint16_t aPort, const string& ip_ /* = "0.0.0.0" */) : port(0), secure(secure_), die(false) {
     sock.create();
     sock.setSocketOpt(SO_REUSEADDR, 1);
-    ip = ip_;
+    ip = SETTING(BIND_IFACE)? sock.getIfaceI4(SETTING(BIND_IFACE_NAME)).c_str() : ip_;
     port = sock.bind(aPort, ip);
     sock.listen();
 
@@ -226,6 +226,11 @@ ConnectionManager::Server::Server(bool secure_, uint16_t aPort, const string& ip
 static const uint32_t POLL_TIMEOUT = 250;
 
 int ConnectionManager::Server::run() noexcept {
+    {
+        char threadName[17];
+        snprintf(threadName, sizeof threadName, "Server_%u", port);
+        setThreadName(threadName);
+    }
     while(!die) {
         try {
             while(!die) {
@@ -366,17 +371,12 @@ void ConnectionManager::on(AdcCommand::SUP, UserConnection* aSource, const AdcCo
     }
 
     bool baseOk = false;
-    bool tigrOk = false;
 
     for(StringIterC i = cmd.getParameters().begin(); i != cmd.getParameters().end(); ++i) {
         if(i->compare(0, 2, "AD") == 0) {
             string feat = i->substr(2);
             if(feat == UserConnection::FEATURE_ADC_BASE || feat == UserConnection::FEATURE_ADC_BAS0) {
                 baseOk = true;
-                // For bas0 tiger is implicit
-                if(feat == UserConnection::FEATURE_ADC_BAS0) {
-                    tigrOk = true;
-                }
                 // ADC clients must support all these...
                 aSource->setFlag(UserConnection::FLAG_SUPPORTS_ADCGET);
                 aSource->setFlag(UserConnection::FLAG_SUPPORTS_MINISLOTS);
@@ -388,8 +388,6 @@ void ConnectionManager::on(AdcCommand::SUP, UserConnection* aSource, const AdcCo
                 aSource->setFlag(UserConnection::FLAG_SUPPORTS_ZLIB_GET);
             } else if(feat == UserConnection::FEATURE_ADC_BZIP) {
                 aSource->setFlag(UserConnection::FLAG_SUPPORTS_XML_BZLIST);
-            } else if(feat == UserConnection::FEATURE_ADC_TIGR) {
-                tigrOk = true;
             }
         }
     }
@@ -446,7 +444,7 @@ void ConnectionManager::on(UserConnectionListener::MyNick, UserConnection* aSour
         return;
     }
 
-    dcassert(aNick.size() > 0);
+    dcassert(!aNick.empty());
     dcdebug("ConnectionManager::onMyNick %p, %s\n", (void*)aSource, aNick.c_str());
     dcassert(!aSource->getUser());
 
