@@ -36,7 +36,7 @@
 #include "ResourceManager.h"
 #include "ThrottleManager.h"
 #include "ADLSearch.h"
-#include "WindowManager.h"
+//#include "WindowManager.h"
 #include "StringTokenizer.h"
 #ifdef LUA_SCRIPT
 #include "ScriptManager.h"
@@ -95,7 +95,7 @@ void startup(void (*f)(void*, const string&), void* p) {
     ADLSearchManager::newInstance();
     ConnectivityManager::newInstance();
     UPnPManager::newInstance();
-    WindowManager::newInstance();
+    //WindowManager::newInstance();
 #ifdef LUA_SCRIPT
     ScriptManager::newInstance();
 #endif
@@ -139,36 +139,30 @@ void startup(void (*f)(void*, const string&), void* p) {
 }
 
 void shutdown() {
-    DynDNS::deleteInstance();
-#ifndef _WIN32 //*nix system
-    ThrottleManager::getInstance()->shutdown();
-#endif
     DebugManager::deleteInstance();
+    DynDNS::deleteInstance();
+#ifdef WITH_DHT
+    dht::DHT::deleteInstance();
+#endif
+    ThrottleManager::getInstance()->shutdown();
 #ifdef LUA_SCRIPT
     ScriptManager::deleteInstance();
 #endif
     TimerManager::getInstance()->shutdown();
     HashManager::getInstance()->shutdown();
 
-#ifdef _WIN32
-    ThrottleManager::getInstance()->shutdown();
-#endif
-
     ConnectionManager::getInstance()->shutdown();
     UPnPManager::getInstance()->close();
 
     BufferedSocket::waitShutdown();
-    WindowManager::getInstance()->prepareSave();
+    //WindowManager::getInstance()->prepareSave();
     QueueManager::getInstance()->saveQueue(true);
     ClientManager::getInstance()->saveUsers();
     if (ipfilter::getInstance())
         ipfilter::getInstance()->shutdown();
     SettingsManager::getInstance()->save();
 
-#ifdef WITH_DHT
-    dht::DHT::deleteInstance();
-#endif
-    WindowManager::deleteInstance();
+    //WindowManager::deleteInstance();
     UPnPManager::deleteInstance();
     ConnectivityManager::deleteInstance();
     ADLSearchManager::deleteInstance();
