@@ -101,7 +101,13 @@ void DirectoryListing::loadFile(const string& name) {
 
 class ListLoader : public dcpp::SimpleXMLReader::CallBack {
 public:
-    ListLoader(DirectoryListing::Directory* root, bool aUpdating) : cur(root), base("/"), inListing(false), updating(aUpdating) {
+    ListLoader(DirectoryListing::Directory* root, bool aUpdating) : cur(root), 
+                                                                    base("/"), 
+                                                                    inListing(false), 
+                                                                    updating(aUpdating),
+                                                                    m_is_mediainfo_list(false),
+                                                                    m_is_first_check_mediainfo_list(false)
+    {
     }
 
     virtual ~ListLoader() { }
@@ -117,6 +123,8 @@ private:
     string base;
     bool inListing;
     bool updating;
+    bool m_is_mediainfo_list;
+    bool m_is_first_check_mediainfo_list;
 };
 
 string DirectoryListing::updateXML(const string& xml) {
@@ -140,6 +148,11 @@ static const string sFile = "File";
 static const string sName = "Name";
 static const string sSize = "Size";
 static const string sTTH = "TTH";
+static const string sBR = "BR";
+static const string sWH = "WH";
+static const string sMVideo = "MV";
+static const string sMAudio = "MA";
+static const string sTS = "TS";
 
 void ListLoader::startTag(const string& name, StringPairList& attribs, bool simple) {
     if(inListing) {
@@ -169,7 +182,27 @@ void ListLoader::startTag(const string& name, StringPairList& attribs, bool simp
                     }
                 }
             }
+            
             DirectoryListing::File* f = new DirectoryListing::File(cur, n, size, tth);
+            
+            string l_ts = "";
+            
+            if (!m_is_first_check_mediainfo_list){
+                m_is_first_check_mediainfo_list = true;
+                l_ts = getAttrib(attribs, sTS, 3);
+                m_is_mediainfo_list = !l_ts.empty();
+            }
+            else if (m_is_mediainfo_list) {
+                l_ts = getAttrib(attribs, sTS, 3);
+            }
+            
+            if (!l_ts.empty()){
+                f->mediaInfo.video_info = getAttrib(attribs, sMVideo, 3);
+                f->mediaInfo.audio_info = getAttrib(attribs, sMAudio, 3);
+                f->mediaInfo.resolution = getAttrib(attribs, sWH, 3);
+                f->mediaInfo.bitrate    = atoi(getAttrib(attribs, sBR, 4).c_str());
+            }
+            
             cur->files.push_back(f);
         } else if(name == sDirectory) {
             const string& n = getAttrib(attribs, sName, 0);
@@ -202,7 +235,7 @@ void ListLoader::startTag(const string& name, StringPairList& attribs, bool simp
         }
     } else if(name == sFileListing) {
         const string& b = getAttrib(attribs, sBase, 2);
-        if(b.size() >= 1 && b[0] == '/' && b[b.size()-1] == '/') {
+        if(!b.empty() && b[0] == '/' && b[b.size()-1] == '/') {
             base = b;
         }
         StringList sl = StringTokenizer<string>(base.substr(1), '/').getTokens();
@@ -342,7 +375,7 @@ private:
 
 struct DirectoryEmpty {
     bool operator()(const DirectoryListing::Directory::Ptr i) const {
-        bool r = i->getFileCount() + i->directories.size() == 0;
+        bool r = i->getFileCount() == 0 && i->directories.empty();
         if (r) DeleteFunction()(i);
         return r;
     }
