@@ -22,13 +22,13 @@
 
 #include "ClientManager.h"
 #include "CryptoManager.h"
-#include "WindowManager.h"
+//#include "WindowManager.h"
 
 #include "HttpConnection.h"
 #include "StringTokenizer.h"
 #include "SimpleXML.h"
 #include "UserCommand.h"
-#include "WindowInfo.h"
+//#include "WindowInfo.h"
 #include "File.h"
 #include "BZUtils.h"
 #include "FilteredFile.h"
