@@ -13,11 +13,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#if !defined(FAVORITE_USER_H)
-#define FAVORITE_USER_H
+#ifndef DCPLUSPLUS_DCPP_FAVORITE_USER_H
+#define DCPLUSPLUS_DCPP_FAVORITE_USER_H
 
 #include "FastAlloc.h"
 #include "User.h"
