@@ -40,10 +40,11 @@ const int64_t HashManager::MIN_BLOCK_SIZE = 64 * 1024;
 
 bool HashManager::checkTTH(const string& aFileName, int64_t aSize, uint32_t aTimeStamp) {
     Lock l(cs);
-    const TTHValue* tth = getFileTTHif(Text::toLower(aFileName));
-    if (tth != NULL) {
+    const TTHValue* tthold = getFileTTHif(Text::toLower(aFileName));
+    const TTHValue* tth = getFileTTHif(aFileName);
+    if (tthold != NULL && tth == NULL) {
         TigerTree tt(MIN_BLOCK_SIZE);
-        store.getTree(*tth, tt);
+        store.getTree(*tthold, tt);
         hashDone(aFileName, aTimeStamp, tt, 0, aSize);
         return true;
     }
@@ -678,6 +679,7 @@ bool HashManager::Hasher::fastHash(const string& filename, uint8_t* , TigerTree&
         return false;
     }
 
+    const int maxHashSpeed = SETTING(MAX_HASH_SPEED);
     int64_t pos = 0;
     int64_t size_read = 0;
     void *buf = NULL;
@@ -734,13 +736,15 @@ bool HashManager::Hasher::fastHash(const string& filename, uint8_t* , TigerTree&
             break;
         }
 
-        if(SETTING(MAX_HASH_SPEED) > 0) {
-        uint64_t now = GET_TICK();
-        uint64_t minTime = size_read * 1000LL / (SETTING(MAX_HASH_SPEED) * 1024LL * 1024LL);
+        if(maxHashSpeed > 0) {
+            uint64_t now = GET_TICK();
+            uint64_t minTime = size_read * 1000LL / (maxHashSpeed * 1024LL * 1024LL);
+            
             if(lastRead + minTime> now) {
-            uint64_t diff = now - lastRead;
-            Thread::sleep(minTime - diff);
+                uint64_t diff = now - lastRead;
+                Thread::sleep(minTime - diff);
             }
+            
             lastRead = lastRead + minTime;
         } else {
             lastRead = GET_TICK();
@@ -786,6 +790,7 @@ bool HashManager::Hasher::fastHash(const string& filename, uint8_t* , TigerTree&
 #endif // !_WIN32
 int HashManager::Hasher::run() {
     setThreadPriority(Thread::IDLE);
+    setThreadName("Hasher");
     uint8_t* buf = NULL;
     bool virtualBuf = true;
     string fname;
@@ -818,7 +823,6 @@ int HashManager::Hasher::run() {
 
         if(!fname.empty()) {
             int64_t size = File::getSize(fname);
-            int64_t sizeLeft = size;
 #ifdef _WIN32
             if(buf == NULL) {
                 virtualBuf = true;
@@ -847,7 +851,6 @@ int HashManager::Hasher::run() {
                 if(sfv.hasCRC())
                 xcrc32 = &crc32;
 
-                size_t n = 0;
                 TigerTree fastTTH(bs);
                 tth = &fastTTH;
 
@@ -859,7 +862,7 @@ int HashManager::Hasher::run() {
                     tth = &slowTTH;
                     crc32 = CRC32Filter();
                     uint64_t lastRead = GET_TICK();
-
+                    size_t n = 0;
                     do {
                         size_t bufSize = BUF_SIZE;
                         if(SETTING(MAX_HASH_SPEED)> 0) {
@@ -881,12 +884,9 @@ int HashManager::Hasher::run() {
                             Lock l(cs);
                             currentSize = max(static_cast<uint64_t>(currentSize - n), static_cast<uint64_t>(0));
                         }
-                        sizeLeft -= n;
 
                     instantPause();
                     } while (n> 0 && !stop);
-                } else {
-                    sizeLeft = 0;
                 }
 
                 f.close();
@@ -960,10 +960,10 @@ void HashManager::on(TimerManagerListener::Second, uint64_t tick) noexcept {
             SM->set(SettingsManager::HASHING_START_DELAY, delay);
         }
 
-        string  curFile;
-        int64_t bytesLeft;
-        size_t  filesLeft = -1;
         if (!ShareManager::getInstance()->isRefreshing()){
+            string  curFile;
+            int64_t bytesLeft;
+            size_t  filesLeft = -1;
             getStats(curFile, bytesLeft, filesLeft);
             //fprintf(stdout,"filesLeft %d\n", filesLeft); fflush(stdout);
 
