@@ -92,7 +92,7 @@ void SearchManager::listen() {
         socket->create(Socket::TYPE_UDP);
         socket->setBlocking(true);
         socket->setSocketOpt(SO_REUSEADDR, 1);
-        port = socket->bind(static_cast<uint16_t>(SETTING(UDP_PORT)), SETTING(BIND_ADDRESS));
+        port = socket->bind(static_cast<uint16_t>(SETTING(UDP_PORT)), SETTING(BIND_IFACE)? socket->getIfaceI4(SETTING(BIND_IFACE_NAME)).c_str() : SETTING(BIND_ADDRESS));
         start();
     } catch(...) {
         socket.reset();
@@ -117,6 +117,7 @@ void SearchManager::disconnect() noexcept {
 
 #define BUFSIZE 8192
 int SearchManager::run() {
+    setThreadName("SearchManager");
     boost::scoped_array<uint8_t> buf(new uint8_t[BUFSIZE]);
     int len;
     sockaddr_in remoteAddr = { 0 };
@@ -170,6 +171,7 @@ int SearchManager::run() {
 }
 
 int SearchManager::UdpQueue::run() {
+    setThreadName("UdpQueue");
     string x = Util::emptyString;
     string remoteIp = Util::emptyString;
     stop = false;
