@@ -13,13 +13,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef DCPLUSPLUS_DCPP_SEARCH_MANAGER_LISTENER_H
 #define DCPLUSPLUS_DCPP_SEARCH_MANAGER_LISTENER_H
 
 #include "forward.h"
+#include "noexcept.h"
 
 namespace dcpp {
 
@@ -31,7 +32,7 @@ public:
     template<int I> struct X { enum { TYPE = I }; };
 
     typedef X<0> SR;
-    virtual void on(SR, const SearchResultPtr&) throw() = 0;
+    virtual void on(SR, const SearchResultPtr&) noexcept = 0;
 };
 
 } // namespace dcpp
