@@ -94,7 +94,9 @@ const string SettingsManager::settingTags[] =
     "SlotsAlternateLimiting", "SlotsPrimaryLimiting", "KeepFinishedFiles",
     "ShowFreeSlotsDesc", "UseIP", "OverLapChunks", "CaseSensitiveFilelist",
     "IpFilter", "TextColor", "UseLua", "AllowNatt", "IpTOSValue", "SegmentSize",
-    "BindIface", "MinimumSearchInterval", "EnableDynDNS", "SENTRY",
+    "BindIface", "MinimumSearchInterval", "EnableDynDNS", "AllowUploadOverMultiHubs",
+    "UseADLOnlyOnOwnList", "AllowSimUploads",
+    "SENTRY",
     // Int64
     "TotalUpload", "TotalDownload",
     "SENTRY",
@@ -297,6 +299,9 @@ SettingsManager::SettingsManager()
     setDefault(MINIMUM_SEARCH_INTERVAL, 60);
     setDefault(DYNDNS_SERVER, "http://checkip.dyndns.org/index.html");
     setDefault(DYNDNS_ENABLE, false);
+    setDefault(ALLOW_UPLOAD_MULTI_HUB, true);
+    setDefault(USE_ADL_ONLY_OWN_LIST, false);
+    setDefault(ALLOW_SIM_UPLOADS, true);
     setSearchTypeDefaults();
 }
 
@@ -588,7 +593,7 @@ bool SettingsManager::getType(const char* name, int& n, int& type) const {
     return false;
 }
 
-const std::string SettingsManager::parseCoreCmd(const std::string cmd) {
+const std::string SettingsManager::parseCoreCmd(const std::string& cmd) {
     StringTokenizer<string> sl(cmd, ' ');
         if (sl.getTokens().size() == 2) {
             int n,type;
