@@ -113,7 +113,8 @@ public:
         SLOTS_ALTERNATE_LIMITING, SLOTS_PRIMARY, KEEP_FINISHED_FILES,
         SHOW_FREE_SLOTS_DESC, USE_IP, OVERLAP_CHUNKS, CASESENSITIVE_FILELIST,
         IPFILTER, TEXT_COLOR, USE_LUA, ALLOW_NATT, IP_TOS_VALUE, SEGMENT_SIZE,
-        BIND_IFACE, MINIMUM_SEARCH_INTERVAL, DYNDNS_ENABLE,
+        BIND_IFACE, MINIMUM_SEARCH_INTERVAL, DYNDNS_ENABLE, ALLOW_UPLOAD_MULTI_HUB,
+        USE_ADL_ONLY_OWN_LIST, ALLOW_SIM_UPLOADS,
         INT_LAST };
 
     enum Int64Setting { INT64_FIRST = INT_LAST + 1,
@@ -218,7 +219,7 @@ public:
 
     void unset(size_t key) { isSet[key] = false; }
 
-    const std::string parseCoreCmd(const std::string cmd);
+    const std::string parseCoreCmd(const std::string& cmd);
 
     void load() {
         Util::migrate(getConfigFile());
@@ -234,7 +235,7 @@ public:
     enum Types {
         TYPE_STRING,
         TYPE_INT,
-        TYPE_INT64,
+        TYPE_INT64
     };
 
     bool getType(const char* name, int& n, int& type) const;
