@@ -469,7 +469,7 @@ void ShareManager::addDirectory(const string& realPath, const string& virtualNam
             }
         }
     }
-    for(list<string>::const_iterator i = removeMap.begin(); i != removeMap.end(); i++) {
+    for(list<string>::const_iterator i = removeMap.begin(); i != removeMap.end(); ++i) {
         removeDirectory(*i);
     }
 
@@ -596,7 +596,7 @@ ShareManager::DirList::const_iterator ShareManager::getByVirtual(const string& v
 
 int64_t ShareManager::getShareSize(const string& realPath) const noexcept {
     Lock l(cs);
-    dcassert(realPath.size()>0);
+    dcassert(!realPath.empty());
     StringMap::const_iterator i = shares.find(realPath);
 
     if(i != shares.end()) {
@@ -743,8 +743,8 @@ void ShareManager::updateIndices(Directory& dir) {
 
     dir.size = 0;
 
-    for(Directory::File::Set::iterator i = dir.files.begin(); i != dir.files.end(); ) {
-        updateIndices(dir, i++);
+    for(Directory::File::Set::iterator i = dir.files.begin(); i != dir.files.end(); ++i) {
+        updateIndices(dir, i);
     }
 }
 
@@ -822,6 +822,7 @@ StringPairList ShareManager::getDirectories() const noexcept {
 }
 
 int ShareManager::run() {
+    setThreadName("ShareManager");
 
     StringPairList dirs = getDirectories();
     // Don't need to refresh if no directories are shared
@@ -1265,7 +1266,7 @@ void ShareManager::search(SearchResultList& results, const string& aString, int
         return;
 
     StringSearch::List ssl;
-    for(StringList::iterator i = sl.begin(); i != sl.end(); ++i) {
+    for(StringIter i = sl.begin(); i != sl.end(); ++i) {
         if(!i->empty()) {
             ssl.push_back(StringSearch(*i));
         }
@@ -1467,7 +1468,7 @@ void ShareManager::on(QueueManagerListener::FileMoved, const string& n) noexcept
     if(BOOLSETTING(ADD_FINISHED_INSTANTLY)) {
         // Check if finished download is supposed to be shared
         Lock l(cs);
-        for(StringMapIter i = shares.begin(); i != shares.end(); i++) {
+        for(StringMapIter i = shares.begin(); i != shares.end(); ++i) {
             if(Util::strnicmp(i->first, n, i->first.size()) == 0 && n[i->first.size() - 1] == PATH_SEPARATOR) {
                 try {
                     // Schedule for hashing, it'll be added automatically later on...
