@@ -41,7 +41,7 @@ TimerManager::TimerManager() {
 }
 
 TimerManager::~TimerManager() {
-    dcassert(listeners.size() == 0);
+    dcassert(listeners.empty());
 }
 
 void TimerManager::shutdown() {
@@ -54,6 +54,7 @@ void TimerManager::shutdown() {
 }
 
 int TimerManager::run() {
+    setThreadName("TimerManager");
     int nextMin = 0;
 #ifdef TIMER_OLD_BOOST
     uint64_t x = getTick();
@@ -87,6 +88,7 @@ int TimerManager::run() {
             nextMin = 0;
         }
     }
+    boostmtx.unlock();
 #endif
 
     dcdebug("TimerManager done\n");
