@@ -41,7 +41,8 @@ namespace dcpp {
 
 static const string UPLOAD_AREA = "Uploads";
 
-UploadManager::UploadManager() noexcept : running(0), extra(0), lastGrant(0), limits(NULL), lastFreeSlots(-1) {
+
+UploadManager::UploadManager() noexcept : extra(0), lastGrant(0), running(0), limits(NULL), lastFreeSlots(-1) {
     ClientManager::getInstance()->addListener(this);
     TimerManager::getInstance()->addListener(this);
 }
@@ -59,6 +60,27 @@ UploadManager::~UploadManager() {
     }
 }
 
+bool UploadManager::hasUpload ( UserConnection& aSource ) {
+    if (!aSource.getSocket() || SETTING(ALLOW_SIM_UPLOADS))
+        return false;
+
+    for ( UploadList::const_iterator i = uploads.begin(); i != uploads.end(); ++i ) {
+        Upload* u = *i;
+        const string l_srcip = aSource.getSocket()->getIp();
+        const int64_t l_share = ClientManager::getInstance()->getBytesShared(aSource.getUser());
+
+        if (u && u->getUserConnection().getSocket() &&
+            l_srcip == u->getUserConnection().getSocket()->getIp() &&
+            u->getUser() && l_share == ClientManager::getInstance()->getBytesShared(u->getUser())
+           )
+        {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 bool UploadManager::prepareFile(UserConnection& aSource, const string& aType, const string& aFile, int64_t aStartPos, int64_t aBytes, bool listRecursive) {
     dcdebug("Preparing %s %s " I64_FMT " " I64_FMT " %d\n", aType.c_str(), aFile.c_str(),
             static_cast<long long int>(aStartPos), static_cast<long long int>(aBytes), listRecursive);
@@ -75,7 +97,6 @@ bool UploadManager::prepareFile(UserConnection& aSource, const string& aType, co
 
     bool userlist = (aFile == Transfer::USER_LIST_NAME_BZ || aFile == Transfer::USER_LIST_NAME);
     bool free = userlist;
-    bool partial = false;
 
     string sourceFile;
     Transfer::Type type;
@@ -96,12 +117,22 @@ bool UploadManager::prepareFile(UserConnection& aSource, const string& aType, co
                 fileSize = size = xml.size();
             } else {
                 {
+                    ShareManager *SM = ShareManager::getInstance();
                     string msg;
                     if ( aFile != Transfer::USER_LIST_NAME_BZ && aFile != Transfer::USER_LIST_NAME &&
-                         !limits.IsUserAllowed(ShareManager::getInstance()->toVirtual(ShareManager::getInstance()->getTTH(aFile)), aSource.getUser(), &msg) )
+                         !limits.IsUserAllowed(SM->toVirtual(SM->getTTH(aFile)), aSource.getUser(), &msg)
+                       )
                     {
                         throw ShareException(msg);
                     }
+                    else if ( aFile != Transfer::USER_LIST_NAME_BZ && aFile != Transfer::USER_LIST_NAME &&
+                              hasUpload(aSource)
+                            )
+                    {
+                        msg = _("Connection already exists.");
+
+                        throw ShareException(msg);
+                    }
                 }
                 File* f = new File(sourceFile, File::READ, File::OPEN);
 
@@ -186,7 +217,6 @@ bool UploadManager::prepareFile(UserConnection& aSource, const string& aType, co
                             is = new LimitedInputStream<true>(is, size);
                     }
 
-                    partial = true;
                     type = Transfer::TYPE_FILE;
                     goto ok;
                 } catch(const Exception&) {
@@ -221,7 +251,6 @@ bool UploadManager::prepareFile(UserConnection& aSource, const string& aType, co
                             is = new LimitedInputStream<true>(is, size);
                         }
 
-                        partial = true;
                         type = Transfer::TYPE_FILE;
                         goto ok;
                     }catch(const Exception&){
@@ -511,11 +540,20 @@ const UploadManager::FileSet& UploadManager::getWaitingUserFiles(const UserPtr&
 }
 
 void UploadManager::addConnection(UserConnectionPtr conn) {
+    Lock l(cs);
+    if (!BOOLSETTING(ALLOW_UPLOAD_MULTI_HUB)) {
+        for(UploadList::iterator i = uploads.begin(); i != uploads.end(); ++i) {
+            if ((*i)->getUserConnection().getRemoteIp() == conn->getRemoteIp()) {
+                conn->disconnect();
+                return;
+            }
+        }
+    }
     if (BOOLSETTING(IPFILTER) && !ipfilter::getInstance()->OK(conn->getRemoteIp(),eDIRECTION_OUT)) {
         conn->error("Your IP is Blocked!");// TODO translate
         LogManager::getInstance()->message(_("IPFilter: Blocked incoming connection to ") + conn->getRemoteIp()); // TODO translate
         //QueueManager::getInstance()->removeSource(conn->getUser(), QueueItem::Source::FLAG_REMOVED);
-        removeConnection(conn);
+        conn->disconnect();
         return;
     }
     conn->addListener(this);
