@@ -111,11 +111,12 @@ public:
         STATE_IDLE, // No more downloads for the moment
 
         // Up & down
-        STATE_RUNNING,      // Transmitting data
+        STATE_RUNNING       // Transmitting data
 
     };
 
     short getNumber() { return (short)((((size_t)this)>>2) & 0x7fff); }
+    BufferedSocket const* getSocket() { return socket; }
 
     // NMDC stuff
     void myNick(const string& aNick) { send("$MyNick " + Text::fromUtf8(aNick, encoding) + '|'); }
