@@ -32,6 +32,7 @@
 #ifdef _WIN32
 #include "w.h"
 #include "shlobj.h"
+#include "lmcons.h"
 #else
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -292,6 +293,22 @@ void Util::migrate(const string& file) {
     File::renameFile(old, file);
 }
 
+string Util::getLoginName() {
+    string loginName = "unknown";
+
+#ifdef _WIN32
+    char winUserName[UNLEN + 1]; // UNLEN is defined in LMCONS.H
+    DWORD winUserNameSize = sizeof(winUserName);
+    if(GetUserNameA(winUserName, &winUserNameSize))
+        loginName = Text::toUtf8(winUserName);
+#else // not _WIN32
+    const char *envUserName = getenv("LOGNAME");
+    loginName = envUserName? Text::toUtf8(envUserName) : loginName;
+#endif // _WIN32
+
+    return loginName;
+}
+
 void Util::loadBootConfig() {
     // Load boot settings
     try {
@@ -411,7 +428,7 @@ string Util::validateFileName(string tmp) {
 }
 
 bool Util::checkExtension(const string& tmp) {
-    for(int i = 0; i < tmp.length(); i++) {
+    for(unsigned int i = 0; i < tmp.length(); i++) {
         if (tmp[i] < 0 || tmp[i] == 32 || tmp[i] == ':') {
             return false;
         }
@@ -690,7 +707,7 @@ vector<string> Util::getLocalIPs() {
 }
 string Util::getLocalIp() {
 #ifdef HAVE_IFADDRS_H
-    return getLocalIPs()[0];
+    return getLocalIPs().empty() ? "0.0.0.0" : getLocalIPs()[0];
 #else
     string tmp;
 
@@ -1146,6 +1163,7 @@ string Util::toAdcFile(const string& file) {
     }
     return ret;
 }
+
 string Util::toNmdcFile(const string& file) {
     if(file.empty())
         return Util::emptyString;
