@@ -13,12 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-
-// Hm...version not updated it seems
-#if defined(HAVE_STLPORT) && (_STLPORT_VERSION < 0x513)
-#error "I use STLport 5.1.3. Remove this if you know what you're doing."
-#endif
