@@ -54,12 +54,10 @@ void cmddebug::add_gui(string file)
 {
     if (file.empty())
         return;
-    string line;
-    line="";
 
     gtk_text_buffer_get_end_iter(buffer, &iter);
 
-    line +=Text::toUtf8("["+Util::getShortTimeString()+"]"+file+"\n\0");
+    string line = Text::toUtf8("["+Util::getTimeString()+"]"+file+"\n\0");
 
     gtk_text_buffer_insert(buffer, &iter, line.c_str(), line.size());
     gtk_text_buffer_get_end_iter(buffer, &iter);
@@ -77,14 +75,15 @@ void cmddebug::add_gui(string file)
 
 }
 
-void cmddebug::ini_client()
+void cmddebug::init()
 {
+    start();
     DebugManager::getInstance()->addListener(this);
 }
 
 void cmddebug::show()
 {
-    ini_client();
+    init();
 }
 
 void cmddebug::on(dcpp::DebugManagerListener::DebugCommand, const std::string& mess, int typedir, const std::string& ip) noexcept
@@ -93,25 +92,25 @@ void cmddebug::on(dcpp::DebugManagerListener::DebugCommand, const std::string& m
             case dcpp::DebugManager::HUB_IN :
                 if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(getWidget("hub_in_button"))) == TRUE)
                 {
-                    addCmd("Hub:\t[Incoming][" + ip + "]\t \t"+mess, ip);
+                    addCmd("Hub:\t[Incoming][" + ip + "]\t\t"+mess, ip);
                 }
                 break;
             case dcpp::DebugManager::HUB_OUT :
                 if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(getWidget("hub_out_button"))) == TRUE)
                 {
-                    addCmd("Hub:\t[Outgoing][" + ip + "]\t \t"+mess, ip);
+                    addCmd("Hub:\t[Outgoing][" + ip + "]\t\t"+mess, ip);
                 }
                 break;
             case dcpp::DebugManager::CLIENT_IN:
                 if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(getWidget("client_in_button"))) == TRUE)
                 {
-                    addCmd("Client:\t[Incoming][" + ip + "]\t \t"+mess, ip);
+                    addCmd("Client:\t[Incoming][" + ip + "]\t\t"+mess, ip);
                 }
                 break;
             case dcpp::DebugManager::CLIENT_OUT:
                 if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(getWidget("client_out_button"))) == TRUE)
                 {
-                    addCmd("Client:\t[Outgoing][" + ip + "]\t \t"+mess, ip);
+                    addCmd("Client:\t[Outgoing][" + ip + "]\t\t"+mess, ip);
                 }
                 break;
             default: break;
@@ -121,15 +120,22 @@ void cmddebug::onScroll_gui(GtkAdjustment *adjustment, gpointer data)
 {
     cmddebug *cmd = (cmddebug *)data;
     gdouble value = gtk_adjustment_get_value(adjustment);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    cmd->scrollToBottom = value >= (gtk_adjustment_get_upper(adjustment) - gtk_adjustment_get_page_size (adjustment));
+#else
     cmd->scrollToBottom = value >= (adjustment->upper-adjustment->page_size);
+#endif
 }
 
 void cmddebug::onResize_gui(GtkAdjustment *adjustment, gpointer data)
 {
     cmddebug *cmd = (cmddebug *)data;
     gdouble value = gtk_adjustment_get_value(adjustment);
-
+#if GTK_CHECK_VERSION(3, 0, 0)
+    if (cmd->scrollToBottom && value < (gtk_adjustment_get_upper(adjustment) - gtk_adjustment_get_page_size (adjustment)))
+#else
     if (cmd->scrollToBottom && value < (adjustment->upper-adjustment->page_size))
+#endif
     {
         GtkTextIter iter;
         gtk_text_buffer_get_end_iter(cmd->buffer, &iter);
@@ -141,16 +147,15 @@ void cmddebug::onResize_gui(GtkAdjustment *adjustment, gpointer data)
 void cmddebug::addCmd(const std::string& cmd,const std::string& ip) {
     string message;
     //g_print("CMD %s\n",cmd.c_str());
+    //g_print("CMDSIZE %d\n",cmdList.size());
+
     if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(getWidget("by_ip_button"))) == TRUE) {
         if (strcmp(gtk_entry_get_text(GTK_ENTRY(getWidget("entrybyip"))),ip.c_str()) == 0)
-            message = cmd;
+            cmdList.push_back(cmd);
     }
     else
-        message = cmd;
-
-    typedef Func1<cmddebug, string> F1;
-    F1 *func = new F1(this, &cmddebug::add_gui, message);
-    WulforManager::get()->dispatchGuiFunc(func);
+        cmdList.push_back(cmd);
+    s.signal();
 }
 
 void cmddebug::on(dcpp::DebugManagerListener::DebugDetection, const std::string& com) noexcept
