@@ -41,7 +41,7 @@ FinishedTransfers* FinishedTransfers::createFinishedUploads()
 }
 
 FinishedTransfers::FinishedTransfers(const EntryType type, const string &title, bool isUpload):
-	BookEntry(type, title, "finishedtransfers.glade"),
+	BookEntry(type, title, "finishedtransfers.ui"),
 	isUpload(isUpload),
 	totalFiles(0),
 	totalUsers(0),
@@ -450,7 +450,7 @@ void FinishedTransfers::onShowOnlyFullFilesToggled_gui(GtkWidget *widget, gpoint
         ft->addFile_gui(params, FALSE);
     }
 
-    FinishedManager::getInstance()->unLockLists();
+    FinishedManager::getInstance()->unlockLists();
 }
 
 void FinishedTransfers::onOpen_gui(GtkMenuItem *item, gpointer data)
@@ -479,7 +479,7 @@ void FinishedTransfers::onOpen_gui(GtkMenuItem *item, gpointer data)
 
 }
 
-void FinishedTransfers::onPageSwitched_gui(GtkNotebook *notebook, GtkNotebookPage *page, guint num, gpointer data)
+void FinishedTransfers::onPageSwitched_gui(GtkNotebook *notebook, GtkNotebook *page, guint num, gpointer data)
 {
 	((FinishedTransfers*)data)->updateStatus_gui(); // Switch the total count between users and files
 }
@@ -648,7 +648,7 @@ void FinishedTransfers::initializeList_client()
 		//WulforManager::get()->dispatchGuiFunc(func);
 	}
 
-	FinishedManager::getInstance()->unLockLists();
+	FinishedManager::getInstance()->unlockLists();
 
 	updateStatus_gui();
 	//WulforManager::get()->dispatchGuiFunc(new Func0<FinishedTransfers>(this, &FinishedTransfers::updateStatus_gui));
@@ -720,7 +720,7 @@ void FinishedTransfers::removeAll_client()
 	FinishedManager::getInstance()->removeAll(isUpload);
 }
 
-void FinishedTransfers::on(FinishedManagerListener::AddedFile, bool upload, const string& file, const FinishedFileItemPtr& item) throw()
+void FinishedTransfers::on(FinishedManagerListener::AddedFile, bool upload, const string& file, const FinishedFileItemPtr& item) noexcept
 {
 	if (isUpload == upload)
 	{
@@ -734,7 +734,7 @@ void FinishedTransfers::on(FinishedManagerListener::AddedFile, bool upload, cons
 }
 
 //NOTE: core 0.762
-void FinishedTransfers::on(FinishedManagerListener::AddedUser, bool upload, const HintedUser &user, const FinishedUserItemPtr &item) throw()
+void FinishedTransfers::on(FinishedManagerListener::AddedUser, bool upload, const HintedUser &user, const FinishedUserItemPtr &item) noexcept
 {
 	if (isUpload == upload)
 	{
@@ -747,7 +747,7 @@ void FinishedTransfers::on(FinishedManagerListener::AddedUser, bool upload, cons
 	}
 }
 
-void FinishedTransfers::on(FinishedManagerListener::UpdatedFile, bool upload, const string& file, const FinishedFileItemPtr& item) throw()
+void FinishedTransfers::on(FinishedManagerListener::UpdatedFile, bool upload, const string& file, const FinishedFileItemPtr& item) noexcept
 {
 	if (isUpload == upload)
 	{
@@ -760,7 +760,7 @@ void FinishedTransfers::on(FinishedManagerListener::UpdatedFile, bool upload, co
 	}
 }
 
-void FinishedTransfers::on(FinishedManagerListener::UpdatedUser, bool upload, const HintedUser &user) throw()//NOTE: core 0.762
+void FinishedTransfers::on(FinishedManagerListener::UpdatedUser, bool upload, const HintedUser &user) noexcept//NOTE: core 0.762
 {
 	if (isUpload == upload)
 	{
@@ -780,7 +780,7 @@ void FinishedTransfers::on(FinishedManagerListener::UpdatedUser, bool upload, co
 	}
 }
 
-void FinishedTransfers::on(FinishedManagerListener::RemovedFile, bool upload, const string& item) throw()
+void FinishedTransfers::on(FinishedManagerListener::RemovedFile, bool upload, const string& item) noexcept
 {
 	if (isUpload == upload)
 	{
@@ -790,7 +790,7 @@ void FinishedTransfers::on(FinishedManagerListener::RemovedFile, bool upload, co
 	}
 }
 
-void FinishedTransfers::on(FinishedManagerListener::RemovedUser, bool upload, const HintedUser &user) throw()//NOTE: core 0.762
+void FinishedTransfers::on(FinishedManagerListener::RemovedUser, bool upload, const HintedUser &user) noexcept//NOTE: core 0.762
 {
 	if (isUpload == upload)
 	{
