@@ -151,6 +151,8 @@ Search::Search():
 
     gtk_combo_box_set_active (GTK_COMBO_BOX(getWidget("comboboxGroupBy")),5);
 
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(getWidget("togglebuttonSidePanel")), TRUE);
+
     // Connect the signals to their callback functions.
     g_signal_connect(getContainer(), "focus-in-event", G_CALLBACK(onFocusIn_gui), (gpointer)this);
     g_signal_connect(getWidget("checkbuttonFilter"), "toggled", G_CALLBACK(onFilterButtonToggled_gui), (gpointer)this);
@@ -181,6 +183,8 @@ Search::Search():
     g_signal_connect(getWidget("comboboxUnit"), "changed", G_CALLBACK(onComboBoxChanged_gui), (gpointer)this);
     g_signal_connect(getWidget("comboboxFile"), "changed", G_CALLBACK(onComboBoxChanged_gui), (gpointer)this);
     g_signal_connect(getWidget("comboboxGroupBy"), "changed", G_CALLBACK(onGroupByComboBoxChanged_gui), (gpointer)this);
+    g_signal_connect(getWidget("togglebuttonSidePanel"), "toggled", G_CALLBACK(onSidePanelToggled_gui), (gpointer)this);
+    g_signal_connect(getWidget("buttonClear"), "clicked", G_CALLBACK(onClearButtonClicked_gui), (gpointer)this);
 }
 
 Search::~Search()
@@ -315,9 +319,9 @@ void Search::popupMenu_gui()
 
     // Add favorite download directories
     StringPairList spl = FavoriteManager::getInstance()->getFavoriteDirs();
-    if (spl.size() > 0)
+    if (!spl.empty())
     {
-        for (StringPairIter i = spl.begin(); i != spl.end(); i++)
+        for (StringPairIter i = spl.begin(); i != spl.end(); ++i)
         {
             menuItem = gtk_menu_item_new_with_label(i->second.c_str());
             g_object_set_data_full(G_OBJECT(menuItem), "fav", g_strdup(i->first.c_str()), g_free);
@@ -370,7 +374,7 @@ void Search::popupMenu_gui()
         StringList targets;
         QueueManager::getInstance()->getTargets(TTHValue(tth), targets);
 
-        if (targets.size() > static_cast<size_t>(0))
+        if (!targets.empty())
         {
             menuItem = gtk_separator_menu_item_new();
             gtk_menu_shell_append(GTK_MENU_SHELL(getWidget("downloadMenu")), menuItem);
@@ -387,9 +391,9 @@ void Search::popupMenu_gui()
 
     spl.clear();
     spl = FavoriteManager::getInstance()->getFavoriteDirs();
-    if (spl.size() > 0)
+    if (!spl.empty())
     {
-        for (StringPairIter i = spl.begin(); i != spl.end(); i++)
+        for (StringPairIter i = spl.begin(); i != spl.end(); ++i)
         {
             menuItem = gtk_menu_item_new_with_label(i->second.c_str());
             g_object_set_data_full(G_OBJECT(menuItem), "fav", g_strdup(i->first.c_str()), g_free);
@@ -480,11 +484,7 @@ void Search::search_gui()
         }
         else
         {
-#if (((GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION >= 24)) || GTK_MAJOR_VERSION > 2)
             gchar *tmp = g_strdup(gtk_entry_get_text (GTK_ENTRY(gtk_bin_get_child(GTK_BIN((GTK_COMBO_BOX(getWidget("comboboxFile"))))))));
-#else
-            gchar *tmp = gtk_combo_box_get_active_text(GTK_COMBO_BOX(getWidget("comboboxFile")));
-#endif
             ftypeStr = tmp;
             g_free(tmp);
             ftype = SearchManager::TYPE_ANY;
@@ -544,6 +544,9 @@ void Search::search_gui()
 
     if (WGETB("clearsearch")) // Only clear if the search was sent.
         gtk_entry_set_text(GTK_ENTRY(searchEntry), "");
+
+    if (gtk_widget_get_visible(getWidget("sidePanel")) && !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(getWidget("checkDontHideSideOnSearch"))))
+        gtk_widget_hide(getWidget("sidePanel"));
 }
 
 void Search::addResult_gui(const SearchResultPtr result)
@@ -555,7 +558,7 @@ void Search::addResult_gui(const SearchResultPtr result)
     bool foundParent = FALSE;
 
     vector<SearchResultPtr> &existingResults = results[result->getUser()->getCID().toBase32()];
-    for (vector<SearchResultPtr>::iterator it = existingResults.begin(); it != existingResults.end(); it++)
+    for (vector<SearchResultPtr>::iterator it = existingResults.begin(); it != existingResults.end(); ++it)
     {
         // Check if it's a duplicate
         if (result->getFile() == (*it)->getFile())
@@ -631,28 +634,28 @@ void Search::addResult_gui(const SearchResultPtr result)
 /*
   * Move top level row to be under a newly created grouping parent.
   */
- GtkTreeIter Search::createParentRow_gui(GtkTreeIter *child, const string &groupStr, gint position /* = -1 */)
- {
-         GtkTreeIter parent;
-         GroupType groupBy = (GroupType)gtk_combo_box_get_active(GTK_COMBO_BOX(getWidget("comboboxGroupBy")));
-         string filename = groupStr;
+GtkTreeIter Search::createParentRow_gui(GtkTreeIter *child, const string &groupStr, gint position /* = -1 */)
+{
+    GtkTreeIter parent;
+    GroupType groupBy = (GroupType)gtk_combo_box_get_active(GTK_COMBO_BOX(getWidget("comboboxGroupBy")));
+    string filename = groupStr;
 
-         // As a special case, use the first child's filename for TTH grouping
-         if (groupBy == TTH)
-                 filename = resultView.getString(child, _("Filename"), GTK_TREE_MODEL(resultStore));
+    // As a special case, use the first child's filename for TTH grouping
+    if (groupBy == TTH)
+         filename = resultView.getString(child, _("Filename"), GTK_TREE_MODEL(resultStore));
 
-         // Insert the new parent row
-         gtk_tree_store_insert_with_values(resultStore, &parent, NULL, position,
-                         resultView.col("Icon"), GTK_STOCK_DND_MULTIPLE,
-                         resultView.col(_("Filename")), filename.c_str(),
-                         -1);
+    // Insert the new parent row
+    gtk_tree_store_insert_with_values(resultStore, &parent, NULL, position,
+                 resultView.col("Icon"), GTK_STOCK_DND_MULTIPLE,
+                 resultView.col(_("Filename")), filename.c_str(),
+                 -1);
 
-         // Move the row to be a child of the new parent
-         GtkTreeIter newChild = WulforUtil::copyRow_gui(resultStore, child, &parent);
-         gtk_tree_store_remove(resultStore, child);
-         *child = newChild;
+    // Move the row to be a child of the new parent
+    GtkTreeIter newChild = WulforUtil::copyRow_gui(resultStore, child, &parent);
+    gtk_tree_store_remove(resultStore, child);
+    *child = newChild;
 
-         return parent;
+    return parent;
 }
 
 
@@ -1077,7 +1080,7 @@ void Search::onDownloadClicked_gui(GtkMenuItem *item, gpointer data)
 {
     Search *s = (Search *)data;
 
-   string target = SETTING(DOWNLOAD_DIRECTORY);
+    string target = SETTING(DOWNLOAD_DIRECTORY);
     s->download_gui(target);
 }
 
@@ -1093,30 +1096,29 @@ void Search::onDownloadToClicked_gui(GtkMenuItem *item, gpointer data)
 {
     Search *s = (Search *)data;
 
-	gint response = gtk_dialog_run(GTK_DIALOG(s->getWidget("dirChooserDialog")));
+    gint response = gtk_dialog_run(GTK_DIALOG(s->getWidget("dirChooserDialog")));
 
-	// Fix crash, if the dialog gets programmatically destroyed.
-	if (response == GTK_RESPONSE_NONE)
-		return;
+    // Fix crash, if the dialog gets programmatically destroyed.
+    if (response == GTK_RESPONSE_NONE)
+        return;
 
-	gtk_widget_hide(s->getWidget("dirChooserDialog"));
+    gtk_widget_hide(s->getWidget("dirChooserDialog"));
 
-	if (response == GTK_RESPONSE_OK)
-	{
-		int count = gtk_tree_selection_count_selected_rows(s->selection);
-		gchar *temp = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(s->getWidget("dirChooserDialog")));
+    if (response == GTK_RESPONSE_OK)
+    {
+        gchar *temp = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(s->getWidget("dirChooserDialog")));
 
-		if (temp)
-		{
-			string target = Text::toUtf8(temp);
-			g_free(temp);
+        if (temp)
+        {
+            string target = Text::toUtf8(temp);
+            g_free(temp);
 
-			if (target[target.length() - 1] != PATH_SEPARATOR)
-				target += PATH_SEPARATOR;
+            if (target[target.length() - 1] != PATH_SEPARATOR)
+                target += PATH_SEPARATOR;
 
-			 s->download_gui(target);
-		}
-	}
+             s->download_gui(target);
+        }
+    }
 }
 
 void Search::onDownloadToMatchClicked_gui(GtkMenuItem *item, gpointer data)
@@ -1311,7 +1313,7 @@ void Search::onSearchByTTHClicked_gui(GtkMenuItem *item, gpointer data)
             {
                 string tth = s->resultView.getString(&iter, _("TTH"));
                 if (!tth.empty())
-                                        s->putValue_gui(tth, 0, SearchManager::SIZE_DONTCARE, SearchManager::TYPE_TTH);
+                    s->putValue_gui(tth, 0, SearchManager::SIZE_DONTCARE, SearchManager::TYPE_TTH);
             }
             gtk_tree_path_free(path);
         }
@@ -1952,3 +1954,23 @@ gboolean Search::searchFilterFunc_gui(GtkTreeModel *model, GtkTreeIter *iter, gp
 
     return TRUE;
 }
+
+void Search::onSidePanelToggled_gui(GtkWidget *widget, gpointer data)
+{
+    Search *s = (Search *)data;
+    GtkWidget *sidepanel = (GtkWidget *)s->getWidget("sidePanel");
+
+    if (gtk_widget_get_visible(sidepanel))
+        gtk_widget_hide(sidepanel);
+    else
+        gtk_widget_show_all(sidepanel);
+}
+
+void Search::onClearButtonClicked_gui(GtkWidget *widget, gpointer data)
+{
+    Search *s = (Search *)data;
+    gtk_tree_store_clear(s->resultStore);
+    s->results.clear();
+    gtk_entry_set_text(GTK_ENTRY(s->searchEntry), "");
+    gtk_entry_set_text(GTK_ENTRY(s->getWidget("entrySize")), "");
+}
