@@ -95,10 +95,7 @@ int main(int argc, char *argv[])
 
     connection = bacon_message_connection_new(GUI_PACKAGE);
 
-    if (connection != NULL)
-        dcdebug("eiskaltdcpp-gtk: connection yes...\n");
-    else
-        dcdebug("eiskaltdcpp-gtk: connection no...\n");
+    dcdebug(connection ? "eiskaltdcpp-gtk: connection yes...\n" : "eiskaltdcpp-gtk: connection no...\n");
 
     // Check if profile is locked
     if (WulforUtil::profileIsLocked())
