@@ -11,10 +11,11 @@
 #include "WulforUtil.h"
 
 #include "dcpp/CID.h"
+#include "dcpp/User.h"
 
 static QStringList toQStringList(const dcpp::StringList &list){
     QStringList ret;
-    for (dcpp::StringList::const_iterator it = list.begin(); it != list.end(); ){
+    for (dcpp::StringList::const_iterator it = list.begin(); it != list.end(); ++it){
         ret.push_back(_q(*it));
     }
 
@@ -33,6 +34,19 @@ ClientManagerScript::~ClientManagerScript(){
     CM->removeListener(this);
 }
 
+
+void ClientManagerScript::sendPM(const QString& cid, const QString& hubUrl, const QString& msg){
+    dcpp::UserPtr user = CM->findUser(CID(_tq(cid)));
+
+    if (user && user->isOnline()){
+        if (msg.isEmpty() || msg == "\n")
+            return;
+
+        CM->privateMessage(HintedUser(user, _tq(hubUrl)), _tq(msg), false);
+    }
+}
+
+
 quint64 ClientManagerScript::getUserCount() const{
     return CM->getUserCount();
 }
@@ -46,14 +60,19 @@ QStringList ClientManagerScript::getHubs(const QString& cid) const{
 }
 
 QStringList ClientManagerScript::getHubNames(const QString& cid) const{
-    StringList hubs = ClientManager::getInstance()->getHubNames(dcpp::CID(_tq(cid)), "");
+    return getHubNames(cid, "");
+}
 
+QStringList ClientManagerScript::getHubNames(const QString& cid, const QString& hubUrl) const{
+    StringList hubs = ClientManager::getInstance()->getHubNames(dcpp::CID(_tq(cid)), _tq(hubUrl));
+    
     if (hubs.empty())
         return QStringList();
     else
         return toQStringList(hubs);
 }
 
+
 QStringList ClientManagerScript::getNicks(const QString& cid) const{
     const dcpp::Identity &user = CM->getOnlineUserIdentity(CM->getUser(dcpp::CID(_tq(cid))));
     QStringList lst;
