@@ -17,9 +17,10 @@
 #include <QClipboard>
 #include <QHeaderView>
 #include <QDir>
+#include <QShortcut>
 
 #include "DownloadQueueModel.h"
-#include "MainWindow.h"
+#include "ArenaWidgetFactory.h"
 #include "SearchFrame.h"
 #include "HubFrame.h"
 #include "HubManager.h"
@@ -38,6 +39,23 @@
 
 using namespace dcpp;
 
+class DownloadQueuePrivate {
+    typedef QMap<QString, QVariant> VarMap;
+    typedef QMap<QString, QMap<QString, QString> > SourceMap;
+    
+public:
+    QShortcut *deleteShortcut;
+
+    DownloadQueueModel *queue_model;
+    DownloadQueueModel *file_model;
+    DownloadQueueDelegate *delegate;
+
+    DownloadQueue::Menu *menu;
+
+    SourceMap sources;
+    SourceMap badSources;
+};
+
 DownloadQueue::Menu::Menu(){
     menu = new QMenu();
     QMenu *menu_magnet = new QMenu(tr("Magnet"), DownloadQueue::getInstance());
@@ -188,7 +206,7 @@ QVariant DownloadQueue::Menu::getArg(){
 }
 
 DownloadQueue::DownloadQueue(QWidget *parent):
-        QWidget(parent)
+        QWidget(parent), d_ptr(new DownloadQueuePrivate())
 {
     setupUi(this);
 
@@ -201,26 +219,19 @@ DownloadQueue::DownloadQueue(QWidget *parent):
 
 DownloadQueue::~DownloadQueue(){
     QueueManager::getInstance()->removeListener(this);
+    Q_D(DownloadQueue);
 
-    delete menu;
+    delete d->menu;
+    delete d_ptr;
 }
 
 void DownloadQueue::closeEvent(QCloseEvent *e){
     if (isUnload()){
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
-        //setAttribute(Qt::WA_DeleteOnClose);
-
         save();
 
         e->accept();
     }
     else {
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -236,7 +247,7 @@ void DownloadQueue::requestDelete(){
 
     QList<DownloadQueueItem*> items;
 
-    foreach (QModelIndex i, list){
+    foreach (const QModelIndex &i, list){
         DownloadQueueItem *item = reinterpret_cast<DownloadQueueItem*>(i.internalPointer());
 
         if (!item)
@@ -260,12 +271,14 @@ void DownloadQueue::requestDelete(){
 }
 
 void DownloadQueue::init(){
-    queue_model = new DownloadQueueModel(this);
+    Q_D(DownloadQueue);
+    
+    d->queue_model = new DownloadQueueModel(this);
 
-    delegate = new DownloadQueueDelegate(queue_model);
+    d->delegate = new DownloadQueueDelegate(d->queue_model);
 
-    treeView_TARGET->setItemDelegate(delegate);
-    treeView_TARGET->setModel(queue_model);
+    treeView_TARGET->setItemDelegate(d->delegate);
+    treeView_TARGET->setModel(d->queue_model);
     treeView_TARGET->setItemsExpandable(true);
     treeView_TARGET->setRootIsDecorated(true);
     treeView_TARGET->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -273,8 +286,8 @@ void DownloadQueue::init(){
 
     label_STATS->hide();
 
-    deleteShortcut = new QShortcut(QKeySequence(Qt::Key_Delete), this);
-    deleteShortcut->setContext(Qt::WidgetWithChildrenShortcut);
+    d->deleteShortcut = new QShortcut(QKeySequence(Qt::Key_Delete), this);
+    d->deleteShortcut->setContext(Qt::WidgetWithChildrenShortcut);
 
     connect(this, SIGNAL(coreAdded(VarMap)),            this, SLOT(addFile(VarMap)), Qt::QueuedConnection);
     connect(this, SIGNAL(coreRemoved(VarMap)),          this, SLOT(remFile(VarMap)), Qt::QueuedConnection);
@@ -283,16 +296,16 @@ void DownloadQueue::init(){
     connect(this, SIGNAL(coreMoved(VarMap)),            this, SLOT(remFile(VarMap)), Qt::QueuedConnection);
     connect(this, SIGNAL(coreMoved(VarMap)),            this, SLOT(addFile(VarMap)), Qt::QueuedConnection);
 
-    connect(deleteShortcut, SIGNAL(activated()), this, SLOT(requestDelete()));
+    connect(d->deleteShortcut, SIGNAL(activated()), this, SLOT(requestDelete()));
     connect(treeView_TARGET, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenu(QPoint)));
     connect(treeView_TARGET->header(), SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotHeaderMenu(QPoint)));
-    connect(queue_model, SIGNAL(needExpand(QModelIndex)), treeView_TARGET, SLOT(expand(QModelIndex)));
-    connect(queue_model, SIGNAL(rowRemoved(QModelIndex)), this, SLOT(slotCollapseRow(QModelIndex)));
-    connect(queue_model, SIGNAL(updateStats(quint64,quint64)), this, SLOT(slotUpdateStats(quint64,quint64)));
+    connect(d->queue_model, SIGNAL(needExpand(QModelIndex)), treeView_TARGET, SLOT(expand(QModelIndex)));
+    connect(d->queue_model, SIGNAL(rowRemoved(QModelIndex)), this, SLOT(slotCollapseRow(QModelIndex)));
+    connect(d->queue_model, SIGNAL(updateStats(quint64,quint64)), this, SLOT(slotUpdateStats(quint64,quint64)));
     connect(pushButton_EXPAND,      SIGNAL(clicked()), treeView_TARGET, SLOT(expandAll()));
     connect(pushButton_COLLAPSE,    SIGNAL(clicked()), treeView_TARGET, SLOT(collapseAll()));
 
-    menu = new Menu();
+    d->menu = new Menu();
 
     setAttribute(Qt::WA_DeleteOnClose);
 
@@ -302,9 +315,7 @@ void DownloadQueue::init(){
 
     treeView_TARGET->expandAll();
 
-    MainWindow *MW = MainWindow::getInstance();
-
-    MW->addArenaWidget(this);
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 void DownloadQueue::load(){
@@ -337,15 +348,16 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
     QueueItem::SourceConstIter it = item->getSources().begin();
 
     for (; it != item->getSources().end(); ++it){
-        UserPtr usr = it->getUser();
+        HintedUser usr = it->getUser();
+        const dcpp::CID &cid = usr.user->getCID();
 
-        if (usr->isOnline())
+        if (usr.user->isOnline())
             ++online;
 
-        nick = WulforUtil::getInstance()->getNicks(usr->getCID());
+        nick = WulforUtil::getInstance()->getNicks(cid, _q(usr.hint));
 
         if (!nick.isEmpty()){
-            source[nick] = _q(usr->getCID().toBase32());
+            source[nick] = _q(cid.toBase32());
             user_list.push_back(nick);
         }
     }
@@ -354,8 +366,10 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
         params["USERS"] = user_list.join(", ");
     else
         params["USERS"] = tr("No users...");
+    
+    Q_D(DownloadQueue);
 
-    sources[_q(item->getTarget())] = source;
+    d->sources[_q(item->getTarget())] = source;
 
     if (item->isWaiting())
         params["STATUS"] = tr("%1 of %2 user(s) online").arg(online).arg(item->getSources().size());
@@ -405,7 +419,7 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
     if (params["ERRORS"].toString().isEmpty())
         params["ERRORS"] = tr("No errors");
 
-    badSources[_q(item->getTarget())] = source;
+    d->badSources[_q(item->getTarget())] = source;
 
     params["ADDED"] = _q(Util::formatTime("%Y-%m-%d %H:%M", item->getAdded()));
     params["TTH"] = _q(item->getTTH().toBase32());
@@ -413,10 +427,12 @@ void DownloadQueue::getParams(DownloadQueue::VarMap &params, const QueueItem *it
 }
 
 QStringList DownloadQueue::getSources(){
-    SourceMap::iterator s_it = sources.begin();
+    Q_D(DownloadQueue);
+    
+    SourceMap::iterator s_it = d->sources.begin();
     QStringList ret;
 
-    for (; s_it != sources.end(); ++s_it){
+    for (; s_it != d->sources.end(); ++s_it){
         QString target = s_it.key();
         QString users;
         QMap<QString, QString>::iterator it = s_it.value().begin();
@@ -442,8 +458,9 @@ void DownloadQueue::removeTarget(const QString &target){
 
 void DownloadQueue::removeSource(const QString &cid, const QString &target){
     QueueManager *QM = QueueManager::getInstance();
+    Q_D(DownloadQueue);
 
-    if (sources.contains(target) && !cid.isEmpty()){
+    if (d->sources.contains(target) && !cid.isEmpty()){
         UserPtr user = ClientManager::getInstance()->findUser(CID(cid.toStdString()));
 
         if (user){
@@ -467,28 +484,38 @@ void DownloadQueue::loadList(){
     }
 
     QueueManager::getInstance()->unlockQueue();
+    
+    Q_D(DownloadQueue);
+    
+    d->queue_model->sort();
 }
 
 void DownloadQueue::addFile(const DownloadQueue::VarMap &map){
-    queue_model->addItem(map);
+    Q_D(DownloadQueue);
+    
+    d->queue_model->addItem(map);
 }
 
 void DownloadQueue::remFile(const VarMap &map){
-    if (queue_model->remItem(map)){
-        SourceMap::iterator it = sources.find(map["TARGET"].toString());
+    Q_D(DownloadQueue);
+    
+    if (d->queue_model->remItem(map)){
+        SourceMap::iterator it = d->sources.find(map["TARGET"].toString());
 
-        if (it != sources.end())
-            sources.erase(it);
+        if (it != d->sources.end())
+            d->sources.erase(it);
 
-        it = badSources.find(map["TARGET"].toString());
+        it = d->badSources.find(map["TARGET"].toString());
 
-        if (it != badSources.end())
-            badSources.erase(it);
+        if (it != d->badSources.end())
+            d->badSources.erase(it);
     }
 }
 
 void DownloadQueue::updateFile(const DownloadQueue::VarMap &map){
-    queue_model->updItem(map);
+    Q_D(DownloadQueue);
+    
+    d->queue_model->updItem(map);
 }
 
 QString DownloadQueue::getCID(const VarMap &map){
@@ -497,7 +524,7 @@ QString DownloadQueue::getCID(const VarMap &map){
 
     VarMap::const_iterator it = map.constBegin();
 
-    return ((++it).value()).toString();
+    return (it.value()).toString();
 }
 
 void DownloadQueue::getChilds(DownloadQueueItem *i, QList<DownloadQueueItem *> &list){
@@ -523,7 +550,7 @@ void DownloadQueue::getItems(const QModelIndexList &list, QList<DownloadQueueIte
     if (list.isEmpty())
         return;
 
-    foreach (QModelIndex i, list){
+    foreach (const QModelIndex &i, list){
         DownloadQueueItem *item = reinterpret_cast<DownloadQueueItem*>(i.internalPointer());
 
         getChilds(item, items);
@@ -548,10 +575,12 @@ void DownloadQueue::slotContextMenu(const QPoint &){
 
     if (target.isEmpty())
         return;
+    
+    Q_D(DownloadQueue);
 
-    Menu::Action act = menu->exec(sources, target, items.size() > 1);
+    Menu::Action act = d->menu->exec(d->sources, target, items.size() > 1);
     QueueManager *QM = QueueManager::getInstance();
-    QVariant arg = menu->getArg();
+    QVariant arg = d->menu->getArg();
     VarMap rmap;
 
     /** Now re-read selected indexes and remove broken items */
@@ -565,7 +594,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
     switch (act){
         case Menu::Alternates:
         {
-            SearchFrame *sf = new SearchFrame();
+            SearchFrame *sf = ArenaWidgetFactory().create<SearchFrame>();
 
             foreach (DownloadQueueItem *i, items)
                 sf->searchAlternates(i->data(COLUMN_DOWNLOADQUEUE_TTH).toString());
@@ -659,7 +688,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
             rmap = arg.toMap();
             QString cid = getCID(rmap);
 
-            if (sources.contains(target) && !cid.isEmpty()){
+            if (d->sources.contains(target) && !cid.isEmpty()){
                 UserPtr user = ClientManager::getInstance()->findUser(CID(cid.toStdString()));
 
                 if (user){
@@ -678,9 +707,14 @@ void DownloadQueue::slotContextMenu(const QPoint &){
             VarMap::const_iterator it = rmap.constBegin();
             dcpp::CID cid(_tq(getCID(rmap)));
             QString nick = ((++it).key());
-            QList<HubFrame*> list = HubManager::getInstance()->getHubs();
+            QList<QObject*> list = HubManager::getInstance()->getHubs();
 
-            foreach (HubFrame *fr, list){
+            foreach (QObject *obj, list){
+                HubFrame *fr = qobject_cast<HubFrame*>(obj);
+                
+                if (!fr)
+                    continue;
+                
                 if (fr->hasCID(cid, nick)){
                     fr->createPMWindow(cid);
 
@@ -695,7 +729,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
             rmap = arg.toMap();
             QString cid = getCID(rmap);
 
-            if (sources.contains(target) && !cid.isEmpty()){
+            if (d->sources.contains(target) && !cid.isEmpty()){
                 UserPtr user = ClientManager::getInstance()->findUser(CID(cid.toStdString()));
 
                 if (user){
@@ -713,7 +747,7 @@ void DownloadQueue::slotContextMenu(const QPoint &){
             rmap = arg.toMap();
             QString cid = getCID(rmap);
 
-            if (sources.contains(target) && !cid.isEmpty()){
+            if (d->sources.contains(target) && !cid.isEmpty()){
                 UserPtr user = ClientManager::getInstance()->findUser(CID(cid.toStdString()));
 
                 if (user){
@@ -763,7 +797,7 @@ void DownloadQueue::slotUpdateStats(quint64 files, quint64 size){
     if (label_STATS->isHidden())
         label_STATS->show();
 
-    label_STATS->setText(QString("Total files: <b>%1</b> Total size: <b>%2</b>").arg(files).arg(WulforUtil::formatBytes(size)));
+    label_STATS->setText(tr("Total files: <b>%1</b> Total size: <b>%2</b>").arg(files).arg(WulforUtil::formatBytes(size)));
 }
 
 void DownloadQueue::slotSettingsChanged(const QString &key, const QString &value){
