@@ -9,10 +9,12 @@
 
 #include "FavoriteHubs.h"
 #include "FavoriteHubModel.h"
-#include "MainWindow.h"
 #include "WulforUtil.h"
 #include "WulforSettings.h"
+#include "VersionGlobal.h"
+#include "MainWindow.h"
 
+#include "dcpp/version.h"
 #include "dcpp/stdinc.h"
 #include "dcpp/FavoriteManager.h"
 #include "dcpp/SettingsManager.h"
@@ -39,27 +41,16 @@ FavoriteHubs::FavoriteHubs(QWidget *parent):
 FavoriteHubs::~FavoriteHubs(){
     FavoriteManager::getInstance()->removeListener(this);
 
-    MainWindow::getInstance()->remArenaWidget(this);
-
     delete model;
 }
 
 void FavoriteHubs::closeEvent(QCloseEvent *e){
     if (isUnload()){
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
         save();
 
-        //setAttribute(Qt::WA_DeleteOnClose);
-
         e->accept();
     }
     else {
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -98,24 +89,28 @@ void FavoriteHubs::init(){
     fakeADCTags = QStringList();
 
     fakeNMDCTags << QString("%1").arg(fullVersionString)
-            << QString("EiskaltDC++ V:%1").arg(VERSIONSTRING)
-            << "++ V:0.75"
             << "++ V:0.777"
+            << "++ V:0.782"
             << "StrgDC++ V:2.42"
             << "ApexDC++ V:1.3.6"
-            << "FlylinkDC++ V:(r400)"
+            << "ApexDC++ V:1.5.1"
+            << "FlylinkDC++ V:r500"
+            << "FlylinkDC++ V:r500-x64"
+            << "FlylinkDC++ V:r501-beta60"
             << "HomeDC++ V:2.22"
-            << "FakeDC V:1.0";
+            << "FakeDC++ V:1.3";
 
     fakeADCTags << QString("%1").arg(fullADCVersionString)
-            << QString("EiskaltDC++ %1").arg(VERSIONSTRING)
-            << "++ 0.75"
             << "++ 0.777"
+            << "++ 0.782"
             << "StrgDC++ 2.42"
             << "ApexDC++ 1.3.6"
-            << "FlylinkDC++ V:(r400)"
+            << "ApexDC++ 1.5.1"
+            << "FlylinkDC++ r500"
+            << "FlylinkDC++ r500-x64"
+            << "FlylinkDC++ r501-beta60"
             << "HomeDC++ 2.22"
-            << "FakeDC 1.0";
+            << "FakeDC++ 1.3";
 
     const FavoriteHubEntryList& fl = FavoriteManager::getInstance()->getFavoriteHubs();
 
@@ -142,9 +137,6 @@ void FavoriteHubs::init(){
     treeView->viewport()->setAcceptDrops(false); // temporary
     treeView->setDragEnabled(false); // temporary
     treeView->setAcceptDrops(false); // temporary
-    //treeView->setDragDropMode(QAbstractItemView::InternalMove);
-
-    MainWindow::getInstance()->addArenaWidget(this);
 
     WulforUtil *WU = WulforUtil::getInstance();
 
@@ -173,6 +165,8 @@ void FavoriteHubs::init(){
     connect(connectButton, SIGNAL(clicked()), this, SLOT(slotConnectButtonClicked()));
 
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
+    
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 void FavoriteHubs::initHubEditor(FavoriteHubEditor &editor){
