@@ -37,7 +37,6 @@
 #include "ArenaWidget.h"
 #include "WulforUtil.h"
 #include "FinishedTransfersModel.h"
-#include "MainWindow.h"
 #include "ShareBrowser.h"
 
 using namespace dcpp;
@@ -99,12 +98,6 @@ public:
 protected:
     virtual void closeEvent(QCloseEvent *e){
         if (isUnload()){
-            MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-            MainWindow::getInstance()->remWidgetFromArena(this);
-            MainWindow::getInstance()->remArenaWidget(this);
-
-            //setAttribute(Qt::WA_DeleteOnClose);
-
             QString key = (comboBox->currentIndex() == 0)? WS_FTRANSFERS_FILES_STATE : WS_FTRANSFERS_USERS_STATE;
             QString state = treeView->header()->saveState().toBase64();
 
@@ -113,9 +106,6 @@ protected:
             e->accept();
         }
         else {
-            MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-            MainWindow::getInstance()->remWidgetFromArena(this);
-
             e->ignore();
         }
     }
@@ -153,7 +143,6 @@ private:
 
         loadList();
 
-        MainWindow::getInstance()->addArenaWidget(this);
         FinishedManager::getInstance()->addListener(this);
 
         setUnload(false);
@@ -177,6 +166,8 @@ private:
 
         slotSwitchOnlyFull(false);
         slotTypeChanged(0);
+        
+        ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
     }
 
     ~FinishedTransfers(){
@@ -405,7 +396,7 @@ private:
         QModelIndexList p_indexes = s_model->selectedRows(0);
         QModelIndexList indexes;
 
-        foreach (QModelIndex i, p_indexes)
+        foreach (const QModelIndex &i, p_indexes)
             indexes.push_back(proxy->mapToSource(i));
 
         if (indexes.size() < 1)
@@ -417,7 +408,7 @@ private:
             FinishedTransfersItem *item = NULL;
             QString file;
 
-            foreach (QModelIndex i, indexes){
+            foreach (const QModelIndex &i, indexes){
                 item = reinterpret_cast<FinishedTransfersItem*>(i.internalPointer());
                 file = item->data(COLUMN_FINISHED_TARGET).toString();
 
@@ -429,7 +420,7 @@ private:
             FinishedTransfersItem *item = NULL;
             QString file_list;
 
-            foreach (QModelIndex i, indexes){
+            foreach (const QModelIndex &i, indexes){
                 item = reinterpret_cast<FinishedTransfersItem*>(i.internalPointer());
                 file_list = item->data(COLUMN_FINISHED_PATH).toString();
 
@@ -438,7 +429,7 @@ private:
                     files.append(file_list.split("; ", QString::SkipEmptyParts));
 #else
                     QStringList s = file_list.split("; ", QString::SkipEmptyParts);
-                    foreach (QString i, s)
+                    foreach (const QString &i, s)
                         files.push_back(i);
 #endif
                 }
@@ -479,7 +470,7 @@ private:
                 else
                     f.prepend("file:///");
 
-                QDesktopServices::openUrl(f);
+                QDesktopServices::openUrl(QUrl(f));
             }
         }
         else if (ret == open_dir){
@@ -491,7 +482,7 @@ private:
                 else
                     f.prepend("file:///");
 
-                QDesktopServices::openUrl(f);
+                QDesktopServices::openUrl(QUrl(f));
             }
         }
 
