@@ -35,13 +35,12 @@
 #include "dcpp/Client.h"
 #include "dcpp/FavoriteManagerListener.h"
 
-#include "UserListModel.h"
 #include "ArenaWidget.h"
-#include "EmoticonFactory.h"
 #include "WulforUtil.h"
 
 class ShellCommandRunner;
 class PMWindow;
+class HubFramePrivate;
 
 using namespace dcpp;
 
@@ -157,10 +156,9 @@ public:
     void requestFocus() { plainTextEdit_INPUT->setFocus(); }
     ArenaWidget::Role role() const { return ArenaWidget::Hub; }
 
-    QString getCIDforNick(QString nick) { return model->CIDforNick(nick, _q(client->getHubUrl())); }
+    QString getCIDforNick(QString nick);
 
 Q_SIGNALS:
-    void newMessage(HubFrame*, const QString &hubUrl, const QString &cid, const QString &nick, const QString &msg);
     void coreConnecting(QString);
     void coreConnected(QString);
     void coreUserUpdated(VarMap map, const dcpp::UserPtr &user, bool join);
@@ -169,18 +167,23 @@ Q_SIGNALS:
     void coreFollow(QString);
     void coreFailed();
     void corePassword();
-    void coreMessage(VarMap);
-    void corePrivateMsg(VarMap);
+    void coreMessage(const VarMap&);
+    void corePrivateMsg(const VarMap&);
     void coreHubUpdated();
     void coreFavoriteUserAdded(QString);
     void coreFavoriteUserRemoved(QString);
     void closeRequest();
+    void highlighted(const VarMap&);
 
 public Q_SLOTS:
     void disableChat();
     void clearChat();
     void addStatus(QString);
+    QString getHubUrl();
+    QString getHubName();
+    QString getMyNick();
     void sendMsg(const QString&);
+    void disablePrivateMessages(bool disable);//disconnect corePrivateMsg from this
 
     void reloadSomeSettings();
     void slotHideFindFrame();
@@ -190,6 +193,7 @@ public Q_SLOTS:
 
     void getStatistic(quint64 &users, quint64 &share) const;
     bool isConnected() const;
+    bool isOP(const QString &nick);
 
     void browseUserFiles(const QString&, bool=false);
 
@@ -287,36 +291,9 @@ private:
     virtual void on(ClientListener::NickTaken, Client*) noexcept;
     virtual void on(ClientListener::SearchFlood, Client*, const string&) noexcept;
 
-    QTimer *updater;
-
-    QMenu *arenaMenu;
-
-    Client *client;
-
-    // Work data
-    QTextCodec *codec;
-
-    quint64 total_shared;
-    QString hub_title;
-
-    bool chatDisabled;
-    bool hasMessages;
-    bool hasHighlightMessages;
-    bool drawLine;
-
-    QStringList status_msg_history;
-    QStringList out_messages;
-    int out_messages_index;
-    bool out_messages_unsent;
-
-    PMMap pm;
-    ShellList shell_list;
-
-    // Userlist data and some helpful functions
-    UserListModel *model;
-    UserListProxyModel *proxy;
-
-    QCompleter * completer;
+    Q_DECLARE_PRIVATE(HubFrame);
+    
+    HubFramePrivate *d_ptr;
 };
 
 Q_DECLARE_METATYPE(HubFrame*)
