@@ -35,9 +35,6 @@ PublicHubs::PublicHubs(QWidget *parent) :
 
     FavoriteManager::getInstance()->addListener(this);
 
-    MainWindow *MW = MainWindow::getInstance();
-    MW->addArenaWidget(this);
-
     QString hubs = _q(SettingsManager::getInstance()->get(SettingsManager::HUBLIST_SERVERS));
 
     comboBox_HUBS->addItems(hubs.split(";"));
@@ -76,6 +73,8 @@ PublicHubs::PublicHubs(QWidget *parent) :
     connect(toolButton_CLOSEFILTER, SIGNAL(clicked()), this, SLOT(slotFilter()));
     connect(comboBox_HUBS, SIGNAL(activated(int)), this, SLOT(slotHubChanged(int)));
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
+    
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 PublicHubs::~PublicHubs(){
@@ -103,18 +102,11 @@ bool PublicHubs::eventFilter(QObject *obj, QEvent *e){
 
 void PublicHubs::closeEvent(QCloseEvent *e){
     if (isUnload()){
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
         WSSET(WS_PUBLICHUBS_STATE, treeView->header()->saveState().toBase64());
 
         e->accept();
     }
     else {
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -160,7 +152,7 @@ void PublicHubs::slotContextMenu(){
 
     if (proxy){
         QModelIndexList list;
-        foreach (QModelIndex i, indexes)
+        foreach (const QModelIndex &i, indexes)
             list.push_back(proxy->mapToSource(i));
         indexes = list;
     }
@@ -182,7 +174,7 @@ void PublicHubs::slotContextMenu(){
         PublicHubItem * item = NULL;
         MainWindow *MW = MainWindow::getInstance();
 
-        foreach (QModelIndex i, indexes){
+        foreach (const QModelIndex &i, indexes){
             item = reinterpret_cast<PublicHubItem*>(i.internalPointer());
 
             if (item)
@@ -194,7 +186,7 @@ void PublicHubs::slotContextMenu(){
     else if (ret == add_fav){
         PublicHubItem * item = NULL;
 
-        foreach (QModelIndex i, indexes){
+        foreach (const QModelIndex &i, indexes){
             item = reinterpret_cast<PublicHubItem*>(i.internalPointer());
 
             if (item && item->entry){
@@ -211,7 +203,7 @@ void PublicHubs::slotContextMenu(){
         PublicHubItem * item = NULL;
         QString out = "";
 
-        foreach (QModelIndex i, indexes){
+        foreach (const QModelIndex &i, indexes){
             item = reinterpret_cast<PublicHubItem*>(i.internalPointer());
 
             if (item)
