@@ -30,6 +30,10 @@
 #include "SearchBlacklistDialog.h"
 #include "WulforUtil.h"
 #include "Magnet.h"
+#include "ArenaWidgetManager.h"
+#include "ArenaWidgetFactory.h"
+#include "DownloadToHistory.h"
+#include "GlobalTimer.h"
 
 #include "dcpp/CID.h"
 #include "dcpp/ClientManager.h"
@@ -199,11 +203,10 @@ SearchFrame::Menu::Action SearchFrame::Menu::exec(QStringList list = QStringList
     QStringList a = aliases.split("\n", QString::SkipEmptyParts);
     QStringList p = paths.split("\n", QString::SkipEmptyParts);
 
-    QString raw = QByteArray::fromBase64(WSGET(WS_DOWNLOAD_DIR_HISTORY).toAscii());
-    QStringList temp_pathes = raw.replace("\r","").split('\n', QString::SkipEmptyParts);
+    QStringList temp_pathes = DownloadToDirHistory::get();
 
     if (!temp_pathes.isEmpty()){
-        foreach (QString t, temp_pathes){
+        foreach (const QString &t, temp_pathes){
             QAction *act = new QAction(WICON(WulforUtil::eiFOLDER_BLUE), QDir(t).dirName(), down_to);
             act->setToolTip(t);
             act->setData(t);
@@ -301,18 +304,10 @@ QMenu *SearchFrame::Menu::buildUserCmdMenu(QList<QString> hub_list){
 }
 
 void SearchFrame::Menu::addTempPath(const QString &path){
-    QString raw = QByteArray::fromBase64(WSGET(WS_DOWNLOAD_DIR_HISTORY).toAscii());
-    QStringList temp_pathes = raw.replace("\r","").split('\n', QString::SkipEmptyParts);
+    QStringList temp_pathes = DownloadToDirHistory::get();
+    temp_pathes.push_front(path);
 
-    if (!temp_pathes.contains(path) && !path.isEmpty() && QDir(path).exists()){
-        temp_pathes.push_front(path);
-
-        if (temp_pathes.count() > 5)
-            temp_pathes.removeLast();
-
-        QString raw = temp_pathes.join("\n");
-        WSSET(WS_DOWNLOAD_DIR_HISTORY, raw.toAscii().toBase64());
-    }
+    DownloadToDirHistory::put(temp_pathes);
 }
 
 SearchFrame::SearchFrame(QWidget *parent):
@@ -325,7 +320,6 @@ SearchFrame::SearchFrame(QWidget *parent):
         results(0L),
         filterShared(SearchFrame::None),
         withFreeSlots(false),
-        timer1(NULL),
         saveFileType(true),
         proxy(NULL),
         completer(NULL),
@@ -367,25 +361,27 @@ SearchFrame::SearchFrame(QWidget *parent):
 SearchFrame::~SearchFrame(){
     Menu::deleteInstance();
 
-    SearchManager::getInstance()->removeListener(this);
-    ClientManager::getInstance()->removeListener(this);
-
-    MainWindow::getInstance()->remArenaWidget(this);
-    MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-
     if (completer)
         completer->deleteLater();
 
     delete model;
-    delete arena_menu;
+    arena_menu->deleteLater();
     delete timer;
     proxy->deleteLater();
 }
 
 void SearchFrame::closeEvent(QCloseEvent *e){
+    SearchManager::getInstance()->removeListener(this);
+    ClientManager::getInstance()->removeListener(this);
+    
+    if (timer)
+        timer->stop();
+    
     save();
 
     setAttribute(Qt::WA_DeleteOnClose);
+    
+    QWidget::disconnect(this, NULL, this, NULL);
 
     e->accept();
 }
@@ -407,9 +403,6 @@ bool SearchFrame::eventFilter(QObject *obj, QEvent *e){
 }
 
 void SearchFrame::init(){
-    timer1 = new QTimer(this);
-    timer1->setInterval(1000);
-
     model = new SearchModel(NULL);
     str_model = new SearchStringListModel(this);
 
@@ -467,7 +460,7 @@ void SearchFrame::init(){
 
     QMenu *m = new QMenu();
 
-    foreach (QString s, searchHistory)
+    foreach (const QString &s, searchHistory)
         m->addAction(s);
 
     focusShortcut = new QShortcut(QKeySequence(Qt::Key_F6), this);
@@ -485,14 +478,14 @@ void SearchFrame::init(){
 
     connect(focusShortcut, SIGNAL(activated()), lineEdit_SEARCHSTR, SLOT(setFocus()));
     connect(focusShortcut, SIGNAL(activated()), lineEdit_SEARCHSTR, SLOT(selectAll()));
-    connect(close_wnd, SIGNAL(triggered()), this, SLOT(close()));
+    connect(close_wnd, SIGNAL(triggered()), this, SLOT(slotClose()));
     connect(pushButton_SEARCH, SIGNAL(clicked()), this, SLOT(slotStartSearch()));
     connect(pushButton_STOP, SIGNAL(clicked()), this, SLOT(slotStopSearch()));
     connect(pushButton_CLEAR, SIGNAL(clicked()), this, SLOT(slotClear()));
     connect(treeView_RESULTS, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(slotResultDoubleClicked(QModelIndex)));
     connect(treeView_RESULTS, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenu(QPoint)));
     connect(treeView_RESULTS->header(), SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotHeaderMenu(QPoint)));
-    connect(timer1, SIGNAL(timeout()), this, SLOT(slotTimer()));
+    connect(GlobalTimer::getInstance(), SIGNAL(second()), this, SLOT(slotTimer()));
     connect(pushButton_SIDEPANEL, SIGNAL(clicked()), this, SLOT(slotToggleSidePanel()));
     connect(lineEdit_SEARCHSTR, SIGNAL(returnPressed()), this, SLOT(slotStartSearch()));
 	connect(lineEdit_SIZE,      SIGNAL(returnPressed()), this, SLOT(slotStartSearch()));
@@ -504,21 +497,13 @@ void SearchFrame::init(){
 
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
 
-    MainWindow *mwnd = MainWindow::getInstance();
-
     load();
 
-    mwnd->addArenaWidget(this);
-    mwnd->addArenaWidgetOnToolbar(this);
-    mwnd->mapWidgetOnArena(this);
-
     setAttribute(Qt::WA_DeleteOnClose);
 
     QList<int> panes = splitter->sizes();
     left_pane_old_size = panes[0];
 
-    timer1->start();
-
     lineEdit_SEARCHSTR->setFocus();
 }
 
@@ -928,17 +913,21 @@ void SearchFrame::slotStartSearch(){
     quint64 llsize = (quint64)lsize;
 
     if (!searchHistory.contains(s)){
-        searchHistory.push_front(s);
+        bool isTTH = WulforUtil::isTTH(s);
+
+        if ((WBGET("memorize-tth-search-phrases", false) && isTTH) || !isTTH)
+            searchHistory.push_front(s);
 
         QMenu *m = new QMenu();
 
-        foreach (QString s, searchHistory)
+        foreach (const QString &s, searchHistory)
             m->addAction(s);
 
         lineEdit_SEARCHSTR->setMenu(m);
 
-        if (searchHistory.count() > 10)
-            searchHistory.removeLast();
+        uint maxItemsNumber = WIGET("search-history-items-number", 10);
+        while (searchHistory.count() > maxItemsNumber)
+                searchHistory.removeLast();
 
         QString hist = searchHistory.join("\n");
         WSSET(WS_SEARCH_HISTORY, hist.toAscii().toBase64());
@@ -1068,7 +1057,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
     if (proxy){
         QModelIndexList _list;
-        foreach (QModelIndex i, list)
+        foreach (const QModelIndex &i, list)
             _list.push_back(proxy->mapToSource(i));
         list = _list;
     }
@@ -1078,7 +1067,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
     QStringList hubs;
 
-    foreach (QModelIndex i, list){
+    foreach (const QModelIndex &i, list){
         SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
         QString host = item->data(COLUMN_SF_HOST).toString();
 
@@ -1095,7 +1084,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::Download:
         {
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1139,7 +1128,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
             old_target = target;
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1166,7 +1155,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::DownloadWholeDir:
         {
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1197,7 +1186,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
 
             old_target = target;
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1215,7 +1204,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only one file
-                    SearchFrame *sf = new SearchFrame();
+                    SearchFrame *sf = ArenaWidgetFactory().create<SearchFrame>();
 
                     sf->searchAlternates(item->data(COLUMN_SF_TTH).toString());
 
@@ -1230,7 +1219,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
             QString magnets = "";
             WulforUtil *WU = WulforUtil::getInstance();
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only files
@@ -1257,7 +1246,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
             QString magnets = "";
             WulforUtil *WU = WulforUtil::getInstance();
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only files
@@ -1283,7 +1272,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
             WulforUtil *WU = WulforUtil::getInstance();
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 if (!item->isDir){//only files
@@ -1305,7 +1294,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::Browse:
         {
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1317,7 +1306,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::MatchQueue:
         {
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1333,13 +1322,13 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
             HubFrame *fr = NULL;
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 QString hubUrl = item->data(COLUMN_SF_HOST).toString();
                 dcpp::CID cid(_tq(item->cid));
 
-                fr = HubManager::getInstance()->getHub(hubUrl);
+                fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
 
                 if (fr)
                     fr->createPMWindow(cid);
@@ -1349,7 +1338,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::AddToFav:
         {
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1362,7 +1351,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::GrantExtraSlot:
         {
-             foreach (QModelIndex i, list){
+             foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1375,7 +1364,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::RemoveFromQueue:
         {
-             foreach (QModelIndex i, list){
+             foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1390,7 +1379,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
              selection_model->clearSelection();
 
-             foreach (QModelIndex i, list){
+             foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
 
                 model->removeItem(item);
@@ -1402,7 +1391,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         }
         case Menu::UserCommands:
         {
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 QString cmd_name = Menu::getInstance()->ucParams["NAME"];
                 QString hub      = Menu::getInstance()->ucParams["HOST"];
@@ -1453,7 +1442,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
         {
             QList <QString> new_inst;
 
-            foreach (QModelIndex i, list){
+            foreach (const QModelIndex &i, list){
                 SearchItem *item = reinterpret_cast<SearchItem*>(i.internalPointer());
                 VarMap params;
 
@@ -1613,6 +1602,10 @@ void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aRe
     emit coreSR(map);
 }
 
+void SearchFrame::slotClose() {
+    ArenaWidgetManager::getInstance()->rem(this);
+}
+
 void SearchFrame::on(ClientConnected, Client* c) noexcept{
     emit coreClientConnected(_q(c->getHubUrl()));
 }
