@@ -66,8 +66,8 @@ class SearchFrame : public QWidget,
 
     typedef QMap<QString, QVariant> VarMap;
 
-    class Menu : public Singleton<Menu>{
-    friend class Singleton<Menu>;
+    class Menu : public dcpp::Singleton<Menu>{
+    friend class dcpp::Singleton<Menu>;
 
     public:
         enum Action{
@@ -164,6 +164,7 @@ private Q_SLOTS:
     void slotStartSearch();
     void slotStopSearch();
     void slotChangeProxyColumn(int);
+    void slotClose();
 
     void slotSettingsChanged(const QString &key, const QString &value);
 
@@ -206,7 +207,6 @@ private:
     QList<dcpp::Client*> client_list;
 
     QTimer *timer;
-    QTimer *timer1;
 
     QCompleter *completer;
 
