@@ -51,7 +51,7 @@ void SettingsGUI::init(){
 
         comboBox_THEMES->addItem(tr("Default (need to restart)"));
 
-        foreach (QString s, styles)
+        foreach (const QString &s, styles)
             comboBox_THEMES->addItem(s);
 
         comboBox_THEMES->setCurrentIndex(styles.indexOf(WSGET(WS_APP_THEME)) >= 0? (styles.indexOf(WSGET(WS_APP_THEME))+1) : 0);
@@ -87,8 +87,8 @@ void SettingsGUI::init(){
                 lang = tr("French");
             else if (f == "pl.qm")
                 lang = tr("Polish");
-            else if (f == "sr.qm")
-                lang = tr("Serbian");
+            else if (f == "sr@latin.qm")
+                lang = tr("Serbian (Latin)");
             else if (f == "uk.qm")
                 lang = tr("Ukrainian");
             else if (f == "es.qm")
@@ -101,6 +101,8 @@ void SettingsGUI::init(){
                 lang = tr("Czech");
             else if (f == "de.qm")
                 lang = tr("German");
+            else if (f == "el.qm")
+                lang = tr("Greek");
 
             if (!lang.isEmpty()){
                 comboBox_LANGS->addItem(lang, full_path);
@@ -120,7 +122,7 @@ void SettingsGUI::init(){
 #endif//WIN32
         i = 0;
         k = -1;
-        foreach (QString f, QDir(users).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
+        foreach (const QString &f, QDir(users).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
             if (!f.isEmpty()){
                 comboBox_USERS->addItem(f);
 
@@ -139,7 +141,7 @@ void SettingsGUI::init(){
 #endif//WIN32
         i = 0;
         k = -1;
-        foreach (QString f, QDir(icons).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
+        foreach (const QString &f, QDir(icons).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
             if (!f.isEmpty()){
                 comboBox_ICONS->addItem(f);
 
@@ -158,7 +160,7 @@ void SettingsGUI::init(){
 #endif//WIN32
         comboBox_EMOT->setCurrentIndex(0);
         i = 0;
-        foreach (QString f, QDir(emot).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
+        foreach (const QString &f, QDir(emot).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
             if (!f.isEmpty()){
                 comboBox_EMOT->addItem(f);
 
