@@ -14,6 +14,9 @@
 #include "SearchFrame.h"
 #include "Magnet.h"
 #include "ShareBrowserSearch.h"
+#include "ArenaWidgetManager.h"
+#include "ArenaWidgetFactory.h"
+#include "DownloadToHistory.h"
 
 #include "dcpp/SettingsManager.h"
 #include "dcpp/FavoriteManager.h"
@@ -136,11 +139,10 @@ ShareBrowser::Menu::Action ShareBrowser::Menu::exec(const dcpp::UserPtr &user){
     QStringList a = aliases.split("\n", QString::SkipEmptyParts);
     QStringList p = paths.split("\n", QString::SkipEmptyParts);
 
-    QString raw = QByteArray::fromBase64(WSGET(WS_DOWNLOAD_DIR_HISTORY).toAscii());
-    QStringList temp_pathes = raw.replace("\r","").split('\n', QString::SkipEmptyParts);
+    QStringList temp_pathes = DownloadToDirHistory::get();
 
     if (!temp_pathes.isEmpty()){
-        foreach (QString t, temp_pathes){
+        foreach (const QString &t, temp_pathes){
             QAction *act = new QAction(WICON(WulforUtil::eiFOLDER_BLUE), QDir(t).dirName(), down_to);
             act->setToolTip(t);
             act->setData(t);
@@ -200,7 +202,7 @@ ShareBrowser::ShareBrowser(UserPtr user, QString file, QString jump_to):
         list_model(NULL),
         proxy(NULL)
 {
-    setupUi(this);
+    
 
     nick = WulforUtil::getInstance()->getNicks(user->getCID());;
 
@@ -216,9 +218,7 @@ ShareBrowser::ShareBrowser(UserPtr user, QString file, QString jump_to):
         else
             title = tr("Listing: ") + nick;
     }
-
-    setAttribute(Qt::WA_DeleteOnClose);
-
+    
     AsyncRunner *runner = new AsyncRunner(this);
     boost::function<void()> f = boost::bind(&ShareBrowser::buildList, this);
 
@@ -227,7 +227,9 @@ ShareBrowser::ShareBrowser(UserPtr user, QString file, QString jump_to):
     connect(runner, SIGNAL(finished()), runner, SLOT(deleteLater()), Qt::QueuedConnection);
 
     runner->start();
-}
+    
+    setState(state() | ArenaWidget::Hidden);
+ }
 
 ShareBrowser::~ShareBrowser(){
     delete tree_model;
@@ -236,6 +238,8 @@ ShareBrowser::~ShareBrowser(){
 
     delete proxy;
 
+    pathHistory.clear();
+
     Menu::deleteInstance();
 
 #if (HAVE_MALLOC_TRIM)
@@ -246,10 +250,6 @@ ShareBrowser::~ShareBrowser(){
 void ShareBrowser::closeEvent(QCloseEvent *e){
     save();
 
-    MainWindow::getInstance()->remWidgetFromArena(this);
-    MainWindow::getInstance()->remArenaWidget(this);
-    MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-
     QWidget::closeEvent(e);
 }
 
@@ -280,6 +280,14 @@ bool ShareBrowser::eventFilter(QObject *obj, QEvent *e){
 }
 
 void ShareBrowser::init(){
+    setupUi(this);
+
+    setAttribute(Qt::WA_DeleteOnClose);
+    
+    toolButton_UP->setIcon(WICON(WulforUtil::eiTOP));
+    toolButton_FORWARD->setIcon(WICON(WulforUtil::eiNEXT));
+    toolButton_BACK->setIcon(WICON(WulforUtil::eiPREVIOUS));
+    
     frame_FILTER->setVisible(false);
 
     initModels();
@@ -309,7 +317,7 @@ void ShareBrowser::init(){
     connect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
 
-    connect(close_wnd, SIGNAL(triggered()), this, SLOT(close()));
+    connect(close_wnd, SIGNAL(triggered()), this, SLOT(slotClose()));
     connect(toolButton_CLOSEFILTER, SIGNAL(clicked()), this, SLOT(slotFilter()));
 
     connect(treeView_RPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -320,6 +328,9 @@ void ShareBrowser::init(){
     connect(tree_model, SIGNAL(layoutChanged()), this, SLOT(slotLayoutUpdated()));
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
     connect(toolButton_SEARCH, SIGNAL(clicked()), this, SLOT(slotStartSearch()));
+    connect(toolButton_BACK, SIGNAL(clicked()), this, SLOT(slotButtonBack()));
+    connect(toolButton_FORWARD, SIGNAL(clicked()), this, SLOT(slotButtonForward()));
+    connect(toolButton_UP, SIGNAL(clicked()), this, SLOT(slotButtonUp()));
 
     continueInit();
 }
@@ -330,8 +341,10 @@ void ShareBrowser::continueInit(){
 
     load();
 
-    if (user == ClientManager::getInstance()->getMe())
+    if (user == ClientManager::getInstance()->getMe()){
         tree_model->loadRestrictions();
+        list_model->setOwnList(true);
+    }
 
     if (!jump_to.isEmpty()){
         FileBrowserItem *root = tree_model->getRootElem();
@@ -348,9 +361,9 @@ void ShareBrowser::continueInit(){
         }
     }
 
-    MainWindow::getInstance()->addArenaWidget(this);
-    MainWindow::getInstance()->addArenaWidgetOnToolbar(this);
-    MainWindow::getInstance()->mapWidgetOnArena(this);
+    pathHistory.clear();
+    
+    ArenaWidgetManager::getInstance()->activate(this);
 }
 
 
@@ -409,9 +422,7 @@ void ShareBrowser::buildList(){
         ADLSearchManager::getInstance()->matchListing(listing);
     }
     catch (const Exception &e){
-        QMessageBox::critical(this, file, _q(e.what()), QMessageBox::Ok);
-
-        close();
+        LogManager::getInstance()->message(e.what());
     }
 }
 
@@ -455,7 +466,7 @@ void ShareBrowser::goUp(QTreeView *view){
     if (view != treeView_RPANE)
         return;
 
-    QStringList paths = label_PATH->text().split("\\", QString::SkipEmptyParts);
+    QStringList paths = lineEdit_PATH->text().split("\\", QString::SkipEmptyParts);
 
     if (paths.empty())//is it possible?
         return;
@@ -515,7 +526,7 @@ void ShareBrowser::slotRightPaneClicked(const QModelIndex &index){
         return;
     }
 
-    QString parent_path = label_PATH->text();
+    QString parent_path = lineEdit_PATH->text();
     QModelIndex parent_index = tree_model->createIndexForItem(tree_model->createRootForPath(parent_path));
 
     parent_path = parent_path +"\\"+item->data(COLUMN_FILEBROWSER_NAME).toString();
@@ -595,7 +606,7 @@ void ShareBrowser::slotRightPaneSelChanged(const QItemSelection &, const QItemSe
     QModelIndexList list = selection_model->selectedRows(0);
     quint64 selected_size = 0;
 
-    foreach (QModelIndex i, list)
+    foreach (const QModelIndex &i, list)
         selected_size += (reinterpret_cast<FileBrowserItem*>(i.internalPointer()))->data(COLUMN_FILEBROWSER_ESIZE).toULongLong();
 
     QString status = QString(tr("Total size: %1")).arg(WulforUtil::formatBytes(current_size));
@@ -611,6 +622,8 @@ static bool onlyFirstColumn(const QModelIndex &index){
 }
 
 void ShareBrowser::slotLeftPaneSelChanged(const QItemSelection &sel, const QItemSelection &des){
+
+
     QItemSelectionModel *selection_model = treeView_LPANE->selectionModel();
     QModelIndexList selected  = selection_model->selectedRows(0);
 
@@ -620,11 +633,20 @@ void ShareBrowser::slotLeftPaneSelChanged(const QItemSelection &sel, const QItem
     QModelIndex index = selected.at(0);
 
     if (index.isValid()){
+
+        SelPair p;
+
         FileBrowserItem *item = static_cast<FileBrowserItem*>(index.internalPointer());
 
         changeRoot(item->dir);
+        p.dir = item->dir;
+        p.index = index;
 
-        label_PATH->setText(tree_model->createRemotePath(item));
+        lineEdit_PATH->setText(tree_model->createRemotePath(item));
+        p.path_tesxt = tree_model->createRemotePath(item);
+
+        pathHistory.append(p);
+        pathHistory_iter = pathHistory.end();
 
         QModelIndexList deselected_idx = des.indexes();
         QFuture<QModelIndex> dsel_filter    = QtConcurrent::filtered(deselected_idx, onlyFirstColumn);
@@ -659,8 +681,90 @@ void ShareBrowser::slotLeftPaneSelChanged(const QItemSelection &sel, const QItem
                 treeView_RPANE->selectionModel()->select(i, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
                 treeView_RPANE->selectionModel()->setCurrentIndex(i, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
             }
-        }
+        }        
+    }
+}
 
+void ShareBrowser::slotButtonUp(){
+
+    QItemSelectionModel *selection_model = treeView_LPANE->selectionModel();
+    QModelIndexList selected  = selection_model->selectedRows(0);
+
+    if (selected.size() > 1 || selected.empty())
+        return;
+
+    QModelIndex index = selected.at(0);
+
+    if (index.isValid()){
+
+        FileBrowserItem *item = static_cast<FileBrowserItem*>(index.internalPointer());
+
+        if (NULL != item->parent()){
+
+            disconnect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                    this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
+
+            SelPair sparent;
+            sparent.index = index.parent();
+
+            changeRoot(item->parent()->dir);
+            sparent.dir = item->parent()->dir;
+
+            sparent.path_tesxt = tree_model->createRemotePath(item->parent());
+            lineEdit_PATH->setText(tree_model->createRemotePath(item->parent()));
+
+            slotRightPaneClicked(index.parent());
+
+            pathHistory.append(sparent);
+            pathHistory_iter = pathHistory.end();
+
+            connect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                    this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
+        }
+    }
+}
+
+void ShareBrowser::slotButtonBack(){
+    if ( (pathHistory_iter != NULL)
+            && (pathHistory.size() >0)){
+
+        disconnect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
+
+        if(pathHistory.end() == pathHistory_iter || pathHistory.begin() != pathHistory_iter)
+            --pathHistory_iter;
+
+        SelPair sp= *pathHistory_iter;
+        changeRoot(sp.dir);
+        lineEdit_PATH->setText(sp.path_tesxt);
+
+        slotRightPaneClicked(sp.index);
+
+        connect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
+    }
+}
+
+void ShareBrowser::slotButtonForward(){
+    if ( (pathHistory_iter != NULL)
+            && (pathHistory.size() >0)){
+
+        disconnect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
+
+        if (pathHistory.end() == pathHistory_iter)
+            --pathHistory_iter;
+        else if (pathHistory_iter != &pathHistory.last())
+            ++pathHistory_iter;
+
+        SelPair sp= *pathHistory_iter;
+        changeRoot(sp.dir);
+        lineEdit_PATH->setText(sp.path_tesxt);
+
+        slotRightPaneClicked(sp.index);
+
+        connect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
     }
 }
 
@@ -675,7 +779,7 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
     QModelIndexList selected  = selection_model->selectedRows(0);
 
     if (view == treeView_RPANE && treeView_RPANE->model() == proxy){
-        foreach (QModelIndex i, selected)
+        foreach (const QModelIndex &i, selected)
             list.push_back(proxy->mapToSource(i));
     }
     else
@@ -694,7 +798,7 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
         }
         case Menu::Download:
         {
-            foreach (QModelIndex index, list){
+            foreach (const QModelIndex &index, list){
                 FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                 if (item->file)
@@ -723,21 +827,13 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
 
             old_target = target;
 
-            QString raw = QByteArray::fromBase64(WSGET(WS_DOWNLOAD_DIR_HISTORY).toAscii());
-            QStringList temp_pathes = raw.replace("\r","").split('\n', QString::SkipEmptyParts);
-
-            if (!temp_pathes.contains(target)){
-                temp_pathes.push_front(target);
-
-                if (temp_pathes.count() > 5)
-                    temp_pathes.removeLast();
-
-                QString raw = temp_pathes.join("\n");
-                WSSET(WS_DOWNLOAD_DIR_HISTORY, raw.toAscii().toBase64());
-            }
+            QStringList temp_pathes = DownloadToDirHistory::get();
+            temp_pathes.push_front(target);
+            
+            DownloadToDirHistory::put(temp_pathes);
 
             if (!target.isEmpty()){
-                foreach (QModelIndex index, list){
+                foreach (const QModelIndex &index, list){
                     FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                     if (item->file)
@@ -751,12 +847,12 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
         }
         case Menu::Alternates:
         {
-            foreach (QModelIndex index, list){
+            foreach (const QModelIndex &index, list){
                 FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                 if (item->file){//search alternates only for files
                     QString tth = item->data(COLUMN_FILEBROWSER_TTH).toString();
-                    SearchFrame *sf = new SearchFrame();
+                    SearchFrame *sf = ArenaWidgetFactory().create<SearchFrame>();
 
                     sf->searchAlternates(tth);
 
@@ -772,7 +868,7 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
             QString path, tth, magnet;
             qlonglong size;
 
-            foreach (QModelIndex index, list){
+            foreach (const QModelIndex &index, list){
                 FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                 path = item->data(COLUMN_FILEBROWSER_NAME).toString();
@@ -797,7 +893,7 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
             QString path, tth, magnet;
             qlonglong size;
 
-            foreach (QModelIndex index, list){
+            foreach (const QModelIndex &index, list){
                 FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                 path = item->data(COLUMN_FILEBROWSER_NAME).toString();
@@ -821,7 +917,7 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
             QString path, tth, magnet;
             qlonglong size;
 
-            foreach (QModelIndex index, list){
+            foreach (const QModelIndex &index, list){
                 FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                 path = item->data(COLUMN_FILEBROWSER_NAME).toString();
@@ -870,7 +966,7 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
         {
             ShareManager *SM = ShareManager::getInstance();
 
-            foreach (QModelIndex index, list){
+            foreach (const QModelIndex &index, list){
                 FileBrowserItem *item = reinterpret_cast<FileBrowserItem*>(index.internalPointer());
 
                 if (!item)
@@ -962,7 +1058,7 @@ void ShareBrowser::slotFilter(){
 }
 
 void ShareBrowser::slotStartSearch(){
-    ShareBrowserSearch *sb_search = new ShareBrowserSearch(this);
+    ShareBrowserSearch *sb_search = new ShareBrowserSearch(tree_model, this);
 
     sb_search->setSearchRoot(tree_root);
     connect(sb_search, SIGNAL(indexClicked(FileBrowserItem*)), this, SLOT(slotSearchJumpTo(FileBrowserItem*)));
@@ -982,3 +1078,7 @@ void ShareBrowser::slotSettingsChanged(const QString &key, const QString&){
     if (key == WS_TRANSLATION_FILE)
         retranslateUi(this);
 }
+
+void ShareBrowser::slotClose() {
+    ArenaWidgetManager::getInstance()->rem(this);
+}
