@@ -11,10 +11,23 @@
 #include "WulforUtil.h"
 #include "WulforSettings.h"
 #include "MainWindow.h"
+#include "ArenaWidgetManager.h"
+#include "ArenaWidgetFactory.h"
+#include "QuickConnect.h"
+#include "SearchFrame.h"
+#include "ShareBrowser.h"
+#include "GlobalTimer.h"
 
 #include "PMWindow.h"
 
 #include <QPainter>
+#include <QEvent>
+#include <QMenu>
+#include <QItemSelectionModel>
+#include <QFileDialog>
+#include <QDesktopServices>
+#include <QDir>
+#include <QUrl>
 
 #define CREATE_ROOT_EL(a, b, c, d, e) \
     do { \
@@ -31,6 +44,8 @@
             map[ArenaWidget::type_el]->title = text; \
     } while (0)
 
+static const QString &SIDEBAR_SHOW_CLOSEBUTTONS = "mainwindow/sidebar-with-close-buttons";
+    
 SideBarModel::SideBarModel(QObject *parent) :
     QAbstractItemModel(parent)
 {
@@ -198,14 +213,17 @@ void SideBarModel::insertWidget(ArenaWidget *awgt){
         }
     default:
         roots[awgt->role()]->setWdget(awgt);
-        ind = index(roots[awgt->role()]->row(), 0, QModelIndex());
+        
+        SideBarItem *root  = roots[awgt->role()];
+        
+        ind = index(root->row(), 0, QModelIndex());
+        
+        if (root->getWidget() && root->getWidget()->toolButton())
+            root->getWidget()->toolButton()->setChecked(true);
 
         break;
     }
 
-    if (!(typeid(*awgt) == typeid(PMWindow) && WBGET(WB_CHAT_KEEPFOCUS)))
-        emit mapWidget(awgt);
-
     emit layoutChanged();
 }
 
@@ -243,10 +261,29 @@ void SideBarModel::removeWidget(ArenaWidget *awgt){
             break;
         }
     default:
-        break;
+        {
+           SideBarItem *root  = roots[awgt->role()];
+           
+           if (root->getWidget() && root->getWidget()->toolButton())
+               root->getWidget()->toolButton()->setChecked(false);
+           
+           historyPop();
+        }
     }
 }
 
+void SideBarModel::toggled ( ArenaWidget* awgt ) {
+    if (!awgt)
+        return;
+    
+    if (awgt->toolButton()){
+        awgt->toolButton()->setChecked(false);
+        awgt->toolButton()->setCheckable(false);
+    }
+    
+    ArenaWidgetManager::getInstance()->activate(awgt);
+}
+
 bool SideBarModel::hasWidget(ArenaWidget *awgt) const{
     if (!awgt)
         return false;
@@ -292,6 +329,14 @@ void SideBarModel::mapped(ArenaWidget *awgt){
     emit selectIndex(s);
 }
 
+void SideBarModel::updated ( ArenaWidget* awgt ) {
+    if (!(awgt  && (awgt->state() & ArenaWidget::Singleton) && !historyStack.isEmpty()))
+        return;
+    
+    if ((awgt->state() & ArenaWidget::Hidden) && (historyStack.last() == awgt))
+        historyPop();
+}
+
 bool SideBarModel::isRootItem(const SideBarItem *item) const{
     QMap<ArenaWidget::Role, SideBarItem*>::const_iterator it = roots.begin();
 
@@ -435,3 +480,205 @@ QSize SideBarDelegate::sizeHint(const QStyleOptionViewItem &option, const QModel
 
     return QSize( 200, HEIGHT );
 }
+
+SideBarView::SideBarView ( QWidget* parent ) : QTreeView(parent), _model(NULL) {
+    installEventFilter(this);
+
+    _model = new SideBarModel(this);
+    
+    setModel(_model);
+    setItemsExpandable(true);
+    setHeaderHidden(true);
+    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    setContextMenuPolicy(Qt::CustomContextMenu);
+    setItemDelegate(new SideBarDelegate(this));
+    expandAll();
+    
+    connect(ArenaWidgetManager::getInstance(), SIGNAL(activated(ArenaWidget*)), this,   SLOT(activated(ArenaWidget*)));
+    connect(ArenaWidgetManager::getInstance(), SIGNAL(added(ArenaWidget*)),     this,   SLOT(added(ArenaWidget*)));
+    connect(ArenaWidgetManager::getInstance(), SIGNAL(removed(ArenaWidget*)),   this,   SLOT(removed(ArenaWidget*)));
+    connect(ArenaWidgetManager::getInstance(), SIGNAL(activated(ArenaWidget*)), _model, SLOT(mapped(ArenaWidget*)));
+    connect(ArenaWidgetManager::getInstance(), SIGNAL(toggled(ArenaWidget*)),   _model, SLOT(toggled(ArenaWidget*)));
+    connect(ArenaWidgetManager::getInstance(), SIGNAL(updated(ArenaWidget*)),   _model, SLOT(updated(ArenaWidget*)));
+    
+    connect(this, SIGNAL(doubleClicked(QModelIndex)),           this,   SLOT(slotSideBarDblClicked(QModelIndex)));
+    connect(this, SIGNAL(customContextMenuRequested(QPoint)),   this,   SLOT(slotSidebarContextMenu()));
+    connect(this, SIGNAL(clicked(QModelIndex)),                 this,   SLOT(slotSidebarHook(QModelIndex)));
+    connect(this, SIGNAL(clicked(QModelIndex)),                 _model, SLOT(slotIndexClicked(QModelIndex)));
+   
+    
+    connect(GlobalTimer::getInstance(), SIGNAL(second()), _model, SLOT(redraw()));
+    
+    connect(_model,    SIGNAL(mapWidget(ArenaWidget*)),     ArenaWidgetManager::getInstance(),  SLOT(activate(ArenaWidget*)));
+    connect(_model,    SIGNAL(selectIndex(QModelIndex)),    this,                               SLOT(slotWidgetActivated(QModelIndex)));
+}
+
+SideBarView::~SideBarView() {
+
+}
+
+bool SideBarView::eventFilter ( QObject *obj, QEvent *e) {
+    if (obj == this && e->type() == QEvent::Resize) {
+        if (WBGET(SIDEBAR_SHOW_CLOSEBUTTONS, true)){
+            header()->resizeSection(0, contentsRect().width() - 20);
+            header()->resizeSection(1, 18);
+        }
+        else{
+            header()->resizeSection(0, contentsRect().width());
+            header()->resizeSection(1, 0);
+        }
+    }
+    
+    return QObject::eventFilter (obj , e);
+}
+
+void SideBarView::activated ( ArenaWidget *awgt ) {
+    _model->mapped(awgt);
+}
+
+void SideBarView::added ( ArenaWidget *awgt ) {
+    _model->insertWidget(awgt);
+}
+
+void SideBarView::removed ( ArenaWidget *awgt ) {
+    _model->removeWidget(awgt);
+}
+
+void SideBarView::slotSidebarContextMenu(){
+    QItemSelectionModel *s_m = selectionModel();
+    QModelIndexList selected = s_m->selectedRows(0);
+
+    if (selected.size() < 1)
+        return;
+
+    SideBarItem *item = reinterpret_cast<SideBarItem*>(selected.at(0).internalPointer());
+
+    QMenu *menu = NULL;
+    
+    if (item && item->childCount() > 0){
+        menu = new QMenu(this);
+        menu->addAction(WICON(WulforUtil::eiEDITDELETE), tr("Close all"));
+
+        if (menu->exec(QCursor::pos())){
+            QList<SideBarItem*> childs = item->childItems;
+
+            foreach (SideBarItem *i, childs){
+                if (i && i->getWidget())
+                    ArenaWidgetManager::getInstance()->rem(i->getWidget());
+            }
+        }
+        
+        menu->deleteLater();
+    }
+    else if (item && item->getWidget()){
+        menu = item->getWidget()->getMenu();
+        
+        if (!menu && (item->getWidget()->state() & ArenaWidget::Singleton))
+            return;
+
+        if(!menu){
+            menu = new QMenu(this);
+            menu->addAction(WICON(WulforUtil::eiEDITDELETE), tr("Close"));
+
+            if (menu->exec(QCursor::pos()))
+                ArenaWidgetManager::getInstance()->rem(item->getWidget());
+            
+            menu->deleteLater();
+        }
+        else
+            menu->exec(QCursor::pos());
+    }
+}
+
+void SideBarView::slotSidebarHook(const QModelIndex &index){
+    if (index.column() == 1){
+        SideBarItem *item = reinterpret_cast<SideBarItem*>(index.internalPointer());
+
+        if (item->getWidget()){
+            switch (item->getWidget()->role()){
+            case ArenaWidget::Hub:
+            case ArenaWidget::PrivateMessage:
+            case ArenaWidget::Search:
+            case ArenaWidget::ShareBrowser:
+            case ArenaWidget::CustomWidget:
+                ArenaWidgetManager::getInstance()->rem(item->getWidget());
+                break;
+            default:
+                break;
+            }
+        }
+    }
+}
+
+void SideBarView::slotSideBarDblClicked(const QModelIndex &index){
+    if (index.column() != 0)
+        return;
+
+    SideBarItem *item = reinterpret_cast<SideBarItem*>(index.internalPointer());
+
+    if (!_model->isRootItem(item) || item->childCount() > 0)
+        return;
+
+    switch (_model->rootItemRole(item)){
+    case ArenaWidget::Search:
+        {
+            SearchFrame *sf = ArenaWidgetFactory().create<SearchFrame>();
+
+            break;
+        }
+    case ArenaWidget::Hub:
+        {
+            QuickConnect qc;
+
+            qc.exec();
+
+            break;
+        }
+    //FIXME: Next code duplicates methods from MainWindow
+    case ArenaWidget::ShareBrowser:
+        {
+           QString file = QFileDialog::getOpenFileName ( this, tr ( "Choose file to open" ),
+                       QString::fromStdString ( Util::getPath ( Util::PATH_FILE_LISTS ) ),
+                       tr ( "Modern XML Filelists" ) + " (*.xml.bz2);;" +
+                       tr ( "Modern XML Filelists uncompressed" ) + " (*.xml);;" +
+                       tr ( "All files" ) + " (*)" );
+
+            if ( file.isEmpty() )
+                return;
+
+            file = QDir::toNativeSeparators ( file );
+            UserPtr user = dcpp::DirectoryListing::getUserFromFilename ( _tq ( file ) );
+
+            if ( user )
+                ArenaWidgetFactory().create<ShareBrowser, UserPtr, QString, QString> ( user, file, "" );
+            
+            break;
+        }
+    case ArenaWidget::PrivateMessage:
+        {
+             QString f = QFileDialog::getOpenFileName(this, tr("Open log file"),_q(SETTING(LOG_DIRECTORY)), tr("Log files (*.log);;All files (*.*)"));
+
+            if ( !f.isEmpty() ) {
+                f = QDir::toNativeSeparators ( f );
+
+                if ( f.startsWith ( "/" ) )
+                    f = "file://" + f;
+                else
+                    f = "file:///" + f;
+
+                QDesktopServices::openUrl ( QUrl(f) );
+            }
+            
+            break;
+        }
+    default:
+        break;
+    }
+
+    setExpanded(index, true);
+}
+
+void SideBarView::slotWidgetActivated ( QModelIndex i ) {
+    selectionModel()->clearSelection();
+    selectionModel()->select(i, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
+}
