@@ -17,6 +17,7 @@
 #include "SearchFrame.h"
 #include "DownloadQueue.h"
 #include "IPFilter.h"
+#include "ArenaWidgetFactory.h"
 
 #include "dcpp/Util.h"
 #include "dcpp/User.h"
@@ -331,7 +332,7 @@ void TransferView::searchAlternates(const QString &tth){
     if (tth.isEmpty())
         return;
 
-    SearchFrame *sfr = new SearchFrame();
+    SearchFrame *sfr = ArenaWidgetFactory().create<SearchFrame>();
     sfr->searchAlternates(tth);
 }
 
@@ -416,7 +417,7 @@ void TransferView::slotContextMenu(const QPoint &){
 
     QList<TransferViewItem*> items;
 
-    foreach (QModelIndex index, list){
+    foreach (const QModelIndex &index, list){
         TransferViewItem *i = reinterpret_cast<TransferViewItem*>(index.internalPointer());
 
         if (i->childCount() > 0){
@@ -446,14 +447,27 @@ void TransferView::slotContextMenu(const QPoint &){
     case Menu::SearchAlternates:
     {
         QStringList tths;
-
-        foreach(TransferViewItem *i, items){
-            if (!tths.contains(i->tth))
-                tths.push_back(i->tth);
-        }
-
-        foreach (QString tth, tths)
-            searchAlternates(tth);
+        QString tth_str = "";
+        std::for_each(items.begin(), items.end(), 
+                      [&](const TransferViewItem *item) {
+                          tth_str = "";
+                          
+                          if (item->download)
+                            tth_str = item->tth;
+                          else {
+                            const TTHValue *tth = dcpp::HashManager::getInstance()->getFileTTHif(_tq(item->target));
+                
+                            if (tth)
+                                tth_str = _q(tth->toBase32());
+                          }
+                          
+                          if (!tth_str.isEmpty() && !tths.contains(tth_str)){
+                            tths.push_back(tth_str);
+                              
+                            searchAlternates(tth_str);
+                          }
+                      }
+                     );
 
         break;
     }
@@ -535,7 +549,7 @@ void TransferView::slotContextMenu(const QPoint &){
             dcpp::CID cid(_tq(i->cid));
             QString hubUrl = i->data(COLUMN_TRANSFER_HOST).toString();
 
-            fr = HubManager::getInstance()->getHub(hubUrl);
+            fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
 
             if (fr)
                 fr->createPMWindow(cid);
