@@ -17,7 +17,6 @@
 #include <QList>
 #include <QStringList>
 #include <QRegExp>
-#include <QTimer>
 
 #ifndef _WIN32
 #include <limits.h>
@@ -28,6 +27,7 @@
 #include "dcpp/stdinc.h"
 #include "dcpp/User.h"
 #include "dcpp/CID.h"
+#include "dcpp/ClientManager.h"
 
 using namespace dcpp;
 
@@ -37,18 +37,7 @@ namespace dcpp{
     inline uint qHash(const boost::intrusive_ptr<dcpp::User> &ptr){
         ulong key = (ulong)(void*)ptr.get();
 
-#if ULONG_MAX >= 18446744073709551615UL
-        //hash a 64 bit virtual address to a hash table index
-        key = (~key) + (key << 18); // key = (key << 18) - key - 1;
-        key = key ^ (key >> 31);
-        key = key + (key << 2) + (key << 4);
-        key = key ^ (key >> 11);
-        key = key + (key << 6);
-        key = key ^ (key >> 22);
-        return uint(key);
-#else
-        return uint(key);
-#endif
+        return ::qHash(key);
     }
 }
 
@@ -61,20 +50,20 @@ public:
     virtual void sort(int column, Qt::SortOrder order);
 };
 
-#define COLUMN_NICK     0
-#define COLUMN_SHARE    1
-#define COLUMN_COMMENT  2
-#define COLUMN_TAG      3
-#define COLUMN_CONN     4
-#define COLUMN_IP       5
-#define COLUMN_EMAIL    6
+static const unsigned COLUMN_NICK       = 0;
+static const unsigned COLUMN_SHARE      = 1;
+static const unsigned COLUMN_COMMENT    = 2;
+static const unsigned COLUMN_TAG        = 3;
+static const unsigned COLUMN_CONN       = 4;
+static const unsigned COLUMN_IP         = 5;
+static const unsigned COLUMN_EMAIL      = 6;
 
 typedef QHash<QString, QVariant> UserMap;
 
 class UserListItem: public PoolItem<UserListItem> {
 
 public:
-    UserListItem(UserListItem* = NULL);
+    UserListItem(UserListItem* = NULL, dcpp::UserPtr p = dcpp::UserPtr(NULL));
     virtual ~UserListItem();
 
     void appendChild(UserListItem *child);
@@ -86,20 +75,26 @@ public:
     UserListItem *parent();
     QList<UserListItem*> childItems;
 
-    bool isOp: 1;
-    bool fav: 1;
-    QString nick;
-    qulonglong share;
-    QString comm;
-    QString tag;
-    QString conn;
-    QString ip;
-    QString email;
     QString cid;
-    QPixmap *px;
+    
+    inline const dcpp::Identity &getIdentity() { return id; }   
+    QString      getNick() const;
+    qulonglong   getShare() const;
+    QString      getComment() const;
+    QString      getTag() const;
+    QString      getIP() const;
+    QString      getConnection() const;
+    QString      getEmail() const;
+    bool         isOP() const;
+    bool         isFav() const;
+    bool         isAway() const;
+    
+    void         updateIdentity();
+    
     UserPtr ptr;
 private:
     UserListItem *parentItem;
+    dcpp::Identity id;
 };
 
 class UserListModel : public QAbstractItemModel {
@@ -122,21 +117,13 @@ public:
     void clear();
     void removeUser(const UserPtr&);
 
-    void addUser (const UserMap &map, const UserPtr&);
     void addUser (  const QString& nick,
-                    const qlonglong share = 0,
-                    const QString& comment = QString(),
-                    const QString& tag = QString(),
-                    const QString& conn = QString(),
-                    const QString& ip = QString(),
-                    const QString& email = QString(),
-
-                    bool isOp = false,
-                    bool isAway = false,
-                    const QString& speed = QString(),
                     const QString& cid= QString(),
                     const UserPtr& = UserPtr()
                 );
+    
+    void updateUser(const UserPtr&);
+    void updateUser(UserListItem *);
 
     UserListItem *itemForPtr(const UserPtr&);
     UserListItem *itemForNick(const QString&, const QString&);
@@ -161,10 +148,6 @@ public:
     void repaint() { emit layoutChanged(); }
     void repaintItem(const UserListItem *item);
     inline void repaintData(const QModelIndex &left, const QModelIndex &right){ emit dataChanged(left, right); }
-    void needResort();
-
-private slots:
-    void slotResort(){ sort(sortColumn, sortOrder); _needResort = false; users.squeeze();}
 
 private:
     UserListItem *rootItem;
@@ -177,9 +160,6 @@ private:
     Qt::SortOrder sortOrder;
     QRegExp stripper;
 
-    QTimer *t;
-    bool _needResort;
-
     WulforUtil *WU;
 };
 
