@@ -39,11 +39,20 @@
 
 using namespace dcpp;
 
-inline QString _q (const std::string &s) __attribute__((always_inline));
-inline std::string _tq(const QString &s) __attribute__((always_inline));
+#ifndef GCC_VERSION
+#define GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100  + __GNUC_PATCHLEVEL__)
+#endif
 
-inline QString _q (const std::string &s) { return QString::fromStdString(s); }
-inline std::string _tq(const QString &s) { return s.toStdString(); }
+#if  GCC_VERSION >= 40500
+    static const auto _q = [](const std::string &s) { return QString::fromStdString(s); };
+    static const auto _tq = [](const QString &s) { return s.toStdString(); };
+#else
+    inline QString _q (const std::string &s) __attribute__((always_inline));
+    inline std::string _tq(const QString &s) __attribute__((always_inline));
+
+    inline QString _q (const std::string &s) { return QString::fromStdString(s); }
+    inline std::string _tq(const QString &s) { return s.toStdString(); }
+#endif // GCC_VERSION >= 40500
 
 typedef QMap<QString, QVariant> VarMap;
 
@@ -119,6 +128,9 @@ public:
         eiUSERS,
         eiZOOM_IN,
         eiZOOM_OUT,
+        eiTOP,
+        eiNEXT,
+        eiPREVIOUS,
         eiQT_LOGO,
         eiSPEED_LIMIT_ON,
         eiSPEED_LIMIT_OFF,
@@ -143,7 +155,7 @@ public:
 
     const QString &getIconsPath() { return app_icons_path; }
 
-    QPixmap getPixmapForFile(const QString&);
+    const QPixmap &getPixmapForFile(const QString&);
 
     void textToHtml(QString&,bool=true);
 
@@ -175,6 +187,8 @@ public:
     QString compactToolTipText(QString, int, QString);
 
     QMenu *buildUserCmdMenu(const QList<QString> &hub_list, int ctx, QWidget* = 0);
+    
+    static bool isTTH(const QString &text);
 
 public Q_SLOTS:
     const QPixmap &getPixmap(Icons);
