@@ -20,7 +20,12 @@ using namespace std;
 #include "dcpp/QueueManager.h"
 #include "dcpp/HashManager.h"
 #include "dcpp/Thread.h"
-#include "MainWindow.h"
+#include "dcpp/Singleton.h"
+
+#ifdef __HAIKU__
+#include "EiskaltApp_haiku.h"
+#endif
+
 #include "WulforUtil.h"
 #include "WulforSettings.h"
 #include "HubManager.h"
@@ -30,6 +35,14 @@ using namespace std;
 #include "EmoticonFactory.h"
 #include "FinishedTransfers.h"
 #include "QueuedUsers.h"
+#include "ArenaWidgetManager.h"
+#include "ArenaWidgetFactory.h"
+#include "MainWindow.h"
+#include "GlobalTimer.h"
+
+#ifndef __HAIKU__
+#include "EiskaltApp.h"
+#endif
 
 #ifdef USE_ASPELL
 #include "SpellCheck.h"
@@ -74,16 +87,16 @@ void installHandlers();
 void migrateConfig();
 #endif
 
-#else//WIN32
+#else //WIN32
 #include <locale.h>
 #endif
 
 int main(int argc, char *argv[])
-{
+{   
     QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
     setlocale(LC_ALL, "");
 
-    EiskaltApp app(argc, argv);
+    EiskaltApp app(argc, argv, _q(dcpp::Util::getLoginName()+"EDCPP"));
     int ret = 0;
 
     parseCmdLine(app.arguments());
@@ -91,13 +104,13 @@ int main(int argc, char *argv[])
     if (app.isRunning()){
         QStringList args = app.arguments();
         args.removeFirst();//remove path to executable
-
+#ifndef __HAIKU__
         app.sendMessage(args.join("\n"));
-
+#endif
         return 0;
     }
 
-#if !defined (Q_WS_WIN) && !defined (Q_WS_HAIKU)
+#if !defined (Q_WS_WIN) && !defined (__HAIKU__)
     installHandlers();
 #endif
 
@@ -115,6 +128,8 @@ int main(int argc, char *argv[])
     app.setOrganizationName("EiskaltDC++ Team");
     app.setApplicationName("EiskaltDC++ Qt");
     app.setApplicationVersion(EISKALTDCPP_VERSION);
+    
+    GlobalTimer::newInstance();
 
     WulforSettings::newInstance();
     WulforSettings::getInstance()->load();
@@ -132,6 +147,8 @@ int main(int argc, char *argv[])
         std::cout << QObject::tr("Application icons has been loaded").toStdString() << std::endl;
 
     app.setWindowIcon(WICON(WulforUtil::eiICON_APPL));
+    
+    ArenaWidgetManager::newInstance();
 
     MainWindow::newInstance();
     MainWindow::getInstance()->setUnload(!WBGET(WB_TRAY_ENABLED));
@@ -154,19 +171,20 @@ int main(int argc, char *argv[])
 
     Notification::newInstance();
 
-    if (!WBGET(WB_MAINWINDOW_HIDE) || !WBGET(WB_TRAY_ENABLED))
-        MainWindow::getInstance()->show();
-
-    MainWindow::getInstance()->autoconnect();
-    MainWindow::getInstance()->parseCmdLine();
-
 #ifdef USE_JS
     ScriptEngine::newInstance();
+    QObject::connect(ScriptEngine::getInstance(), SIGNAL(scriptChanged(QString)), MainWindow::getInstance(), SLOT(slotJSFileChanged(QString)));
 #endif
-
-    FinishedUploads::newInstance();
-    FinishedDownloads::newInstance();
-    QueuedUsers::newInstance();
+    
+    ArenaWidgetFactory().create< dcpp::Singleton, FinishedUploads >();
+    ArenaWidgetFactory().create< dcpp::Singleton, FinishedDownloads >();
+    ArenaWidgetFactory().create< dcpp::Singleton, QueuedUsers >();
+    
+    MainWindow::getInstance()->autoconnect();
+    MainWindow::getInstance()->parseCmdLine();
+    
+    if (!WBGET(WB_MAINWINDOW_HIDE) || !WBGET(WB_TRAY_ENABLED))
+        MainWindow::getInstance()->show();
 
     ret = app.exec();
 
@@ -185,11 +203,17 @@ int main(int argc, char *argv[])
 #ifdef USE_JS
     ScriptEngine::deleteInstance();
 #endif
+    
+    ArenaWidgetManager::deleteInstance();
+    
+    HubManager::getInstance()->release();
 
     MainWindow::deleteInstance();
 
     WulforUtil::deleteInstance();
     WulforSettings::deleteInstance();
+    
+    GlobalTimer::deleteInstance();
 
     dcpp::shutdown();
 
@@ -204,7 +228,7 @@ int main(int argc, char *argv[])
 }
 
 void parseCmdLine(const QStringList &args){
-    foreach (QString arg, args){
+    foreach (const QString &arg, args){
         if (arg == "-h" || arg == "--help"){
             About().printHelp();
 
@@ -218,7 +242,26 @@ void parseCmdLine(const QStringList &args){
     }
 }
 
-#if !defined (Q_WS_WIN) && !defined (Q_WS_HAIKU)
+#if !defined (Q_WS_WIN) && !defined (__HAIKU__)
+
+void catchSIGSEGV(int sigNum) {
+    std::cout << "Catching SIGSEGV signal..." << std::endl;
+
+#ifdef ENABLE_STACKTRACE
+    printBacktrace(sigNum);
+#endif // ENABLE_STACKTRACE
+    
+    EiskaltApp *eapp = dynamic_cast<EiskaltApp*>(qApp);
+    
+    if (eapp) {
+        eapp->getSharedMemory().unlock();
+        eapp->getSharedMemory().detach();
+    }
+    
+    raise(SIGINT);
+    
+    std::abort();
+}
 
 void installHandlers(){
     struct sigaction sa;
@@ -228,9 +271,7 @@ void installHandlers(){
         std::cout << QObject::tr("Cannot handle SIGPIPE").toStdString() << std::endl;
     }
 
-#ifdef ENABLE_STACKTRACE
-    signal(SIGSEGV, printBacktrace);
-#endif // ENABLE_STACKTRACE
+    signal(SIGSEGV, catchSIGSEGV);
 
     std::cout << QObject::tr("Signal handlers installed.").toStdString() << std::endl;
 }
@@ -252,7 +293,7 @@ void copy(const QDir &from, const QDir &to){
     if (!from_path.endsWith(QDir::separator()))
         from_path += QDir::separator();
 
-    foreach (QString s, from.entryList(QDir::Dirs)){
+    foreach (const QString &s, from.entryList(QDir::Dirs)){
         QDir new_dir(to_path+s);
 
         if (new_dir.exists())
@@ -265,7 +306,7 @@ void copy(const QDir &from, const QDir &to){
         }
     }
 
-    foreach (QString f, from.entryList(QDir::Files)){
+    foreach (const QString &f, from.entryList(QDir::Files)){
         QFile orig(from_path+f);
 
         if (!orig.copy(to_path+f))
